# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentTypeEnum(object):

    """Implementation of the 'PaymentTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        CREDIT_CARD: TODO: type description here.
        MAIL_CHECK: TODO: type description here.
        BOOKING_PAL_MOR: TODO: type description here.

    """

    CREDIT_CARD = 'CREDIT_CARD'

    MAIL_CHECK = 'MAIL_CHECK'

    BOOKING_PAL_MOR = 'BOOKING_PAL_MOR'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeetaxTypeEnum(object):

    """Implementation of the 'FeetaxTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        TAXABLE: TODO: type description here.
        NOT_TAXABLE: TODO: type description here.

    """

    TAXABLE = 'TAXABLE'

    NOT_TAXABLE = 'NOT_TAXABLE'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservationRateNotifcationModel(object):

    """Implementation of the 'ReservationRateNotifcationModel' model.

    TODO: type model description here.

    Attributes:
        original_rack_rate (float): Original rack rate. Rate received from PMS
            (rate without additional channel commission or any additional
            markup)
        net_rate (float): Net rate (rate which PM will get - so without any
            additional commissions).
        new_published_rack_rate (float): New published rack rate (rate which
            guest paid - rate with all commissions).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "original_rack_rate":'originalRackRate',
        "net_rate":'netRate',
        "new_published_rack_rate":'newPublishedRackRate'
    }

    def __init__(self,
                 original_rack_rate=None,
                 net_rate=None,
                 new_published_rack_rate=None):
        """Constructor for the ReservationRateNotifcationModel class"""

        # Initialize members of the class
        self.original_rack_rate = original_rack_rate
        self.net_rate = net_rate
        self.new_published_rack_rate = new_published_rack_rate


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        original_rack_rate = dictionary.get('originalRackRate')
        net_rate = dictionary.get('netRate')
        new_published_rack_rate = dictionary.get('newPublishedRackRate')

        # Return an object of this model
        return cls(original_rack_rate,
                   net_rate,
                   new_published_rack_rate)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Image(object):

    """Implementation of the 'Image' model.

    TODO: type model description here.

    Attributes:
        url (string): URL of the image
        tags (list of ImageTagsEnum): imagesText of main description. Tags
            codes are given in Appendix.
        url_mbp (string): URL of the image on MyBookingPal. This field will be
            only in response. You can not send this in request.
        sort (int): Sort of the image. Image with the lowest sort number will
            be set as main. This field will be only in response. You can not
            send this in request.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url":'url',
        "tags":'tags',
        "url_mbp":'urlMbp',
        "sort":'sort'
    }

    def __init__(self,
                 url=None,
                 tags=None,
                 url_mbp=None,
                 sort=None):
        """Constructor for the Image class"""

        # Initialize members of the class
        self.url = url
        self.tags = tags
        self.url_mbp = url_mbp
        self.sort = sort


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        tags = dictionary.get('tags')
        url_mbp = dictionary.get('urlMbp')
        sort = dictionary.get('sort')

        # Return an object of this model
        return cls(url,
                   tags,
                   url_mbp,
                   sort)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class PetPolicy(object):

    """Implementation of the 'PetPolicy' model.

    TODO: type model description here.

    Attributes:
        allowed_pets (AllowedPetsTypeEnum): TODO: type description here.
        charge_pets (string): Charge parking. Example: “Free”, “$ 100”.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "allowed_pets":'allowedPets',
        "charge_pets":'chargePets'
    }

    def __init__(self,
                 allowed_pets=None,
                 charge_pets=None):
        """Constructor for the PetPolicy class"""

        # Initialize members of the class
        self.allowed_pets = allowed_pets
        self.charge_pets = charge_pets


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        allowed_pets = dictionary.get('allowedPets')
        charge_pets = dictionary.get('chargePets')

        # Return an object of this model
        return cls(allowed_pets,
                   charge_pets)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservationpushResponse(object):

    """Implementation of the 'ReservationpushResponse' model.

    This is response which the BookingPal expect to get on from PMS on push
    POST request for create/cancel reservation

    Attributes:
        alt_id (string): Id of reservation in your system
        is_error (bool): Did you have error during processing of request
            (true) or not (false)
        code (string): Code of message
        message (string): Text info message. If you have any error please put
            here detail message.
        transaction_state (string): This field should be returned only if you
            are processing payment. With information did you process payment
            or not. Allowed values [Accepted, Failed].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "alt_id":'altId',
        "is_error":'is_error',
        "code":'code',
        "message":'message',
        "transaction_state":'transactionState'
    }

    def __init__(self,
                 alt_id=None,
                 is_error=False,
                 code=None,
                 message=None,
                 transaction_state=None):
        """Constructor for the ReservationpushResponse class"""

        # Initialize members of the class
        self.alt_id = alt_id
        self.is_error = is_error
        self.code = code
        self.message = message
        self.transaction_state = transaction_state


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        alt_id = dictionary.get('altId')
        is_error = dictionary.get("is_error") if dictionary.get("is_error") else False
        code = dictionary.get('code')
        message = dictionary.get('message')
        transaction_state = dictionary.get('transactionState')

        # Return an object of this model
        return cls(alt_id,
                   is_error,
                   code,
                   message,
                   transaction_state)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser
import apimaticcalculatorlatest.models.reservation_fee_notification_model
import apimaticcalculatorlatest.models.reservation_tax_notification_model
import apimaticcalculatorlatest.models.reservation_commissions_notification_model
import apimaticcalculatorlatest.models.reservation_rate_notifcation_model

class Reservationnotificationobject(object):

    """Implementation of the 'Reservationnotificationobject' model.

    TODO: type model description here.

    Attributes:
        reservation_id (string): Id of the reservation in BookingPal
        product_id (string): Id of the product in BookingPal
        supplier_id (string): Id of the property manager
        agent_name (string): Agent name/Channel name
        confirmation_id (string): Channel confirmation code
        unique_key (string): Unique code to identify that the request is from
            BookingPal. This value is unique for every PMS (and it will be
            different in different environments).
        new_state (string): Reservation state
        customer_name (string): Guest full name (in format firstName,
            lastName)
        from_date (date): Reservation date from. Date is in format
            "yyyy-MM-dd"
        to_date (date): Reservation date to. Date is in format "yyyy-MM-dd"
        adult (int): number of adults
        child (int): number of children
        address (string): Guest address
        city (string): Guest city
        zip (string): Guest zip code
        country (string): Guest country
        state (string): Guest state
        email (string): Guest email
        phone (string): Guest phone
        notes (string): Guest notes
        credit_card_type (string): Credit card type
        credit_card_number (string): Credit card number
        credit_card_expiration_month (string): Credit card expiration month
        credit_card_expiration_year (string): Credit card expiration yea
        credit_card_cid (string): Credit card cid
        total (float): Best available rate (This is the total value that
            guests will pay, including rate, fees, taxes, and all commissions.
            )
        fees (list of ReservationFeeNotificationModel): List of models
        taxes (list of ReservationTaxNotificationModel): List of models
        commission (ReservationCommissionsNotificationModel): TODO: type
            description here.
        rate (ReservationRateNotifcationModel): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reservation_id":'reservationId',
        "product_id":'productId',
        "supplier_id":'supplierId',
        "agent_name":'agentName',
        "confirmation_id":'confirmationId',
        "unique_key":'uniqueKey',
        "new_state":'newState',
        "customer_name":'customerName',
        "from_date":'fromDate',
        "to_date":'toDate',
        "adult":'adult',
        "child":'child',
        "email":'email',
        "total":'total',
        "fees":'fees',
        "taxes":'taxes',
        "commission":'commission',
        "rate":'rate',
        "address":'address',
        "city":'city',
        "zip":'zip',
        "country":'country',
        "state":'state',
        "phone":'phone',
        "notes":'notes',
        "credit_card_type":'creditCardType',
        "credit_card_number":'creditCardNumber',
        "credit_card_expiration_month":'creditCardExpirationMonth',
        "credit_card_expiration_year":'creditCardExpirationYear',
        "credit_card_cid":'creditCardCid'
    }

    def __init__(self,
                 reservation_id=None,
                 product_id=None,
                 supplier_id=None,
                 agent_name=None,
                 confirmation_id=None,
                 unique_key=None,
                 new_state=None,
                 customer_name=None,
                 from_date=None,
                 to_date=None,
                 adult=None,
                 child=None,
                 email=None,
                 total=None,
                 fees=None,
                 taxes=None,
                 commission=None,
                 rate=None,
                 address=None,
                 city=None,
                 zip=None,
                 country=None,
                 state=None,
                 phone=None,
                 notes=None,
                 credit_card_type=None,
                 credit_card_number=None,
                 credit_card_expiration_month=None,
                 credit_card_expiration_year=None,
                 credit_card_cid=None):
        """Constructor for the Reservationnotificationobject class"""

        # Initialize members of the class
        self.reservation_id = reservation_id
        self.product_id = product_id
        self.supplier_id = supplier_id
        self.agent_name = agent_name
        self.confirmation_id = confirmation_id
        self.unique_key = unique_key
        self.new_state = new_state
        self.customer_name = customer_name
        self.from_date = from_date
        self.to_date = to_date
        self.adult = adult
        self.child = child
        self.address = address
        self.city = city
        self.zip = zip
        self.country = country
        self.state = state
        self.email = email
        self.phone = phone
        self.notes = notes
        self.credit_card_type = credit_card_type
        self.credit_card_number = credit_card_number
        self.credit_card_expiration_month = credit_card_expiration_month
        self.credit_card_expiration_year = credit_card_expiration_year
        self.credit_card_cid = credit_card_cid
        self.total = total
        self.fees = fees
        self.taxes = taxes
        self.commission = commission
        self.rate = rate


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        reservation_id = dictionary.get('reservationId')
        product_id = dictionary.get('productId')
        supplier_id = dictionary.get('supplierId')
        agent_name = dictionary.get('agentName')
        confirmation_id = dictionary.get('confirmationId')
        unique_key = dictionary.get('uniqueKey')
        new_state = dictionary.get('newState')
        customer_name = dictionary.get('customerName')
        from_date = dateutil.parser.parse(dictionary.get('fromDate')).date() if dictionary.get('fromDate') else None
        to_date = dateutil.parser.parse(dictionary.get('toDate')).date() if dictionary.get('toDate') else None
        adult = dictionary.get('adult')
        child = dictionary.get('child')
        email = dictionary.get('email')
        total = dictionary.get('total')
        fees = None
        if dictionary.get('fees') != None:
            fees = list()
            for structure in dictionary.get('fees'):
                fees.append(apimaticcalculatorlatest.models.reservation_fee_notification_model.ReservationFeeNotificationModel.from_dictionary(structure))
        taxes = None
        if dictionary.get('taxes') != None:
            taxes = list()
            for structure in dictionary.get('taxes'):
                taxes.append(apimaticcalculatorlatest.models.reservation_tax_notification_model.ReservationTaxNotificationModel.from_dictionary(structure))
        commission = apimaticcalculatorlatest.models.reservation_commissions_notification_model.ReservationCommissionsNotificationModel.from_dictionary(dictionary.get('commission')) if dictionary.get('commission') else None
        rate = apimaticcalculatorlatest.models.reservation_rate_notifcation_model.ReservationRateNotifcationModel.from_dictionary(dictionary.get('rate')) if dictionary.get('rate') else None
        address = dictionary.get('address')
        city = dictionary.get('city')
        zip = dictionary.get('zip')
        country = dictionary.get('country')
        state = dictionary.get('state')
        phone = dictionary.get('phone')
        notes = dictionary.get('notes')
        credit_card_type = dictionary.get('creditCardType')
        credit_card_number = dictionary.get('creditCardNumber')
        credit_card_expiration_month = dictionary.get('creditCardExpirationMonth')
        credit_card_expiration_year = dictionary.get('creditCardExpirationYear')
        credit_card_cid = dictionary.get('creditCardCid')

        # Return an object of this model
        return cls(reservation_id,
                   product_id,
                   supplier_id,
                   agent_name,
                   confirmation_id,
                   unique_key,
                   new_state,
                   customer_name,
                   from_date,
                   to_date,
                   adult,
                   child,
                   email,
                   total,
                   fees,
                   taxes,
                   commission,
                   rate,
                   address,
                   city,
                   zip,
                   country,
                   state,
                   phone,
                   notes,
                   credit_card_type,
                   credit_card_number,
                   credit_card_expiration_month,
                   credit_card_expiration_year,
                   credit_card_cid)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class NearbyAmenitiesEnum(object):

    """Implementation of the 'NearbyAmenitiesEnum' enum.

    List of allowed Nearby Amenities codes

    Attributes:
        ACC1: TODO: type description here.
        ACC203: TODO: type description here.
        ACC65: TODO: type description here.
        HAC199: TODO: type description here.
        RST5: TODO: type description here.

    """

    ACC1 = 'ACC1'

    ACC203 = 'ACC203'

    ACC65 = 'ACC65'

    HAC199 = 'HAC199'

    RST5 = 'RST5'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData
from apimaticcalculatorlatest.models.reservationpush_response import ReservationpushResponse

class RequestToBookController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def create_requestto_book_test(self,
                                   body):
        """Does a POST request to /requestToBookTest.

        Since you can not get the request to book on our test environment
        (since this first needs to be created on the channel) We provide the
        possibility for PMS to test this request with some random filled data
        in our system. So when you call this API function - we will send you
        push notification for the request to book for a provided property ID.

        Args:
            body (RequesttoBookTestRequest): TODO: type description here.
                Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/requestToBookTest'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def create_requestto_book_answerfrom_pms(self,
                                             content_type,
                                             body):
        """Does a POST request to /requestToBook.

        This is an API call which you should use for accepting on avoiding
        requests to book.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (RequesttoBookAnswerfromPMSRequest): TODO: type description
                here. Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/requestToBook'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def create_requestto_book_request(self,
                                      body):
        """Does a POST request to /.

        This will be a request which we will send to PMS when we get a request
        to book from the channel.
        So when BookingPal gets a new request to book request - we will push
        this POST request to the link which you set in BookingPal for your PMS
        (in Push Notification section - "requestToBook"). 
        Important note: In this doc to be able to test this - you need to set
        a full URL on the Configure button in the right section.

        Args:
            body (RequestToBookRequestModel): TODO: type description here.
                Example: 

        Returns:
            ReservationpushResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ReservationpushResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequestToBookDeclineReasonTypeEnum(object):

    """Implementation of the 'RequestToBookDeclineReasonTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        DATES_NOT_AVAILABLE: TODO: type description here.
        NOT_A_GOOD_FIT: TODO: type description here.
        WAITING_FOR_BETTER_RESERVATION: TODO: type description here.
        NOT_COMFORTABLE: TODO: type description here.

    """

    DATES_NOT_AVAILABLE = 'DATES_NOT_AVAILABLE'

    NOT_A_GOOD_FIT = 'NOT_A_GOOD_FIT'

    WAITING_FOR_BETTER_RESERVATION = 'WAITING_FOR_BETTER_RESERVATION'

    NOT_COMFORTABLE = 'NOT_COMFORTABLE'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.reservation_get_response import ReservationGetResponse

class ReservationNotificationsController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_reservationby_product(self,
                                  product_id):
        """Does a GET request to /reservation/{productId}.

        This function allows logged-in users to get all reservations for the
        specific product.

        Args:
            product_id (string): Product ID

        Returns:
            ReservationGetResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/reservation/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ReservationGetResponse.from_dictionary)

    def get_reservationby_pm(self):
        """Does a GET request to /reservation.

        This API call will return a list of reservations that belong to the
        current user.

        Returns:
            ReservationGetResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/reservation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ReservationGetResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class Yield(object):

    """Implementation of the 'Yield' model.

    TODO: type model description here.

    Attributes:
        begin_date (date): From date. Date should be in format "yyyy-MM-dd"
        end_date (date): To date. Date should be in format "yyyy-MM-dd"
        amount (float): Yield amount
        modifier (YieldmodifierEnum): TODO: type description here.
        weekend_param (WeekendParamEnum): TODO: type description here.
        param (int): Parameter. It can verify depending on what YMR was set.
            More details about params you can see in the description above.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "begin_date":'beginDate',
        "end_date":'endDate',
        "amount":'amount',
        "modifier":'modifier',
        "weekend_param":'weekendParam',
        "param":'param'
    }

    def __init__(self,
                 begin_date=None,
                 end_date=None,
                 amount=None,
                 modifier=None,
                 weekend_param=None,
                 param=None):
        """Constructor for the Yield class"""

        # Initialize members of the class
        self.begin_date = begin_date
        self.end_date = end_date
        self.amount = amount
        self.modifier = modifier
        self.weekend_param = weekend_param
        self.param = param


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        begin_date = dateutil.parser.parse(dictionary.get('beginDate')).date() if dictionary.get('beginDate') else None
        end_date = dateutil.parser.parse(dictionary.get('endDate')).date() if dictionary.get('endDate') else None
        amount = dictionary.get('amount')
        modifier = dictionary.get('modifier')
        weekend_param = dictionary.get('weekendParam')
        param = dictionary.get('param')

        # Return an object of this model
        return cls(begin_date,
                   end_date,
                   amount,
                   modifier,
                   weekend_param,
                   param)





__all__ = [
    'authorization',
    'createnew_update_property_manager_request',
    'property_managerdetailsresponse',
    'nearby_amenity',
    'image_urlfor_create',
    'image_url_list',
    'createandupdate_los_request',
    'los_rate',
    'fee_tax_response',
    'p_ms',
    'payment',
    'text',
    'bed',
    'available_count',
    'phone',
    'getimagelistbyproduct_id',
    'image',
    'createandupdateratesandavailability_request',
    'split_payment',
    'payment_gateways',
    'productresponse',
    'lo_sratesresponse',
    'company_address',
    'bedroom',
    'parking_policy',
    'api_responsewithout_data',
    'manual_policy',
    'manual_policies',
    'fee_tax_mandatory',
    'create_update_property_request',
    'max_stay_model',
    'restriction',
    'createfeeandtax_request',
    'createimages_request',
    'notes',
    'rates_availabilityresponse',
    'los_rates_product',
    'taxes',
    'description_text_model',
    'pet_policy',
    'min_stay_model',
    'fee',
    'credit_card',
    'beds',
    'deletelistofimages_request',
    'policy',
    'check_out',
    'property',
    'bedroom_configuration',
    'rates_availability',
    'availability_model',
    'fee_tax',
    'internet_policy',
    'location',
    'policies',
    'company_details',
    'cancellation_policy',
    'payment_policy',
    'get_p_mslist',
    'attributes_with_quantity',
    'property_list_request',
    'company',
    'rate',
    'check_in',
    'fee_tax_mandatory_setting',
    'myield',
    'push_notification_links_model',
    'validation_property_i_ds_list',
    'threads_model',
    'yieldresponse',
    'push_notification_links_request',
    'create_yield_request',
    'message_model',
    'setfeeandtaxvalidationsetting_request',
    'getmessagethreads_response',
    'requestto_book_answerfrom_pms_request',
    'functions_request_to_book',
    'requestto_book_test_request',
    'message_request_from_supplier',
    'getmessagelistforspecificthread_response',
    'fee_tax_validation_settings',
    'transport_yield',
    'validationfor_listofproperties_request',
    'push_notification_links_response',
    'fee_tax_validation_setting_response',
    'thread',
    'messages_model',
    'postnewmessageforspecificthread_request',
    'functions_request_to_book_test',
    'reservationnotificationobject',
    'asynchronous_validationmodel',
    'reservation_fee_notification_model',
    'validation_asynchronouspushmessagerequest',
    'reservation_commissions_notification_model',
    'cancel_reservationnotificationobject',
    'request_to_book_request_model',
    'reservation_get_response',
    'reservationpush_response',
    'reservation_rate_notifcation_model',
    'request_to_book_cancel_request_model',
    'reservation_tax_notification_model',
    'time_cost_parking_enum',
    'channel_abb_enum',
    'fee_unit_enum',
    'weekend_param_enum',
    'user_enum',
    'credit_card_list_enum',
    'located_parking_type_enum',
    'manual_policy_type_enum',
    'payment_policy_type_enum',
    'type_enum',
    'feetax_type_enum',
    'fee_value_type_enum',
    'requestto_book_test_action_enum',
    'payment_gateways_type_enum',
    'fee_type_enum',
    'yieldmodifier_enum',
    'space_unit_enum',
    'credit_card_type_enum',
    'request_to_book_decline_reason_type_enum',
    'kindof_internet_type_enum',
    'nearby_amenities_enum',
    'deposit_type_enum',
    'reservation_parking_type_enum',
    'payment_type_enum',
    'allowed_pets_type_enum',
    'amenity_types_enum',
    'fee_entity_type_enum',
    'request_to_book_type_enum',
    'property_types_enum',
    'bedroom_type_enum',
    'available_internet_enum',
    'taxis_type_enum',
    'cancellation_policy_type_enum',
    'bed_configuration_enum',
    'image_tags_enum',
    'asynchronouspushmessagetype_enum',
    'multi_unit_enum',
]


# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CheckOut(object):

    """Implementation of the 'CheckOut' model.

    TODO: type model description here.

    Attributes:
        monday (bool): Determines if check out could be made on monday
        tuesday (bool): Determines if check out could be made on tuesday
        wednesday (bool): Determines if check out could be made on wednesday
        thursday (bool): Determines if check out could be made on thursday
        friday (bool): Determines if check out could be made on friday
        saturday (bool): Determines if check out could be made on saturday
        sunday (bool): Determines if check out could be made on sunday

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "monday":'monday',
        "tuesday":'tuesday',
        "wednesday":'wednesday',
        "thursday":'thursday',
        "friday":'friday',
        "saturday":'saturday',
        "sunday":'sunday'
    }

    def __init__(self,
                 monday=None,
                 tuesday=None,
                 wednesday=None,
                 thursday=None,
                 friday=None,
                 saturday=None,
                 sunday=None):
        """Constructor for the CheckOut class"""

        # Initialize members of the class
        self.monday = monday
        self.tuesday = tuesday
        self.wednesday = wednesday
        self.thursday = thursday
        self.friday = friday
        self.saturday = saturday
        self.sunday = sunday


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        monday = dictionary.get('monday')
        tuesday = dictionary.get('tuesday')
        wednesday = dictionary.get('wednesday')
        thursday = dictionary.get('thursday')
        friday = dictionary.get('friday')
        saturday = dictionary.get('saturday')
        sunday = dictionary.get('sunday')

        # Return an object of this model
        return cls(monday,
                   tuesday,
                   wednesday,
                   thursday,
                   friday,
                   saturday,
                   sunday)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData

class ValidationController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_booking_pal_validationjob_full_pm(self):
        """Does a GET request to /validation.

        This function will allow the PMC to call the BookingPal property
        validation job for all properties identified which belong to the
        current user. Authorization token should be on PM level. 
        Also we will run validation only for properties which are activated.
        If you deactivate property - we will not validate this property.
        After the request you will get a response indicating if messages were
        processed or not. If the request is good your request for the
        validator job will be put into a queue. Once the request is processed,
        BookingPal will send an async push message per property informing the
        user if a property is valid or not, and if it is not valid - with
        reasons why the validation failed. This message will be sent on the
        endpoint which was entered in section Push Notifications, field
        asyncPush.
        Note: If the property is distributed already on some channel - this
        property will not be moved to an Incomplete state. Also if you have
        property on Incomplete state because of some reason, and you update
        this data which causes that property is on ‘Incomplete’ property will
        not be moved automatically to a valid state. Instead, you should run a
        Validation job manually for that property or wait for our automatic
        validation job which we are running once per day. 
        To make the property ready for Onboarding you should run validation
        first. if the property is valid - it will be ready for onboarding.
        Otherwise - the property will be in Incomplete state. Also, we will
        run validation only for properties that are activated. If you
        deactivate property - we will not validate this property.

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/validation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def create_booking_pal_validationjob_listofproperties(self,
                                                          content_type,
                                                          body):
        """Does a POST request to /validation.

        This function will allow the PMS to call the BookingPal property
        validation job for a list of properties from request. These properties
        must belong to the current user and authorization token should be on
        PM level.
        Also, we will run validation only for properties that are activated.
        If you deactivate property - we will not validate this property.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (ValidationforListofpropertiesRequest): TODO: type
                description here. Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/validation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ChannelABBEnum(object):

    """Implementation of the 'ChannelABBEnum' enum.

    TODO: type enum description here.

    Attributes:
        BKG: TODO: type description here.
        ABB: TODO: type description here.
        EXP: TODO: type description here.
        EXP_HC: TODO: type description here.
        HAC: TODO: type description here.

    """

    BKG = 'BKG'

    ABB = 'ABB'

    EXP = 'EXP'

    EXP_HC = 'EXP_HC'

    HAC = 'HAC'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BedroomTypeEnum(object):

    """Implementation of the 'BedroomTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        BEDROOM: TODO: type description here.
        ENUM_LIVING ROOM: TODO: type description here.

    """

    BEDROOM = 'Bedroom'

    ENUM_LIVING_ROOM = 'Living Room'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData
from apimaticcalculatorlatest.models.getimagelistbyproduct_id import GetimagelistbyproductID

class ImagesController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def createimages(self,
                     content_type,
                     body):
        """Does a POST request to /image.

        This function allows the logged in user to upload images for the
        existing product. Every new image will be sorted to the end. The first
        image sent will be used as the “Main Image”. (Image re-ordering can
        also be done within the BookingPal platform manually by users)

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateimagesRequest): TODO: type description here. Example:
                
        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/image'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def getimagelistbyproduct_id(self,
                                 product_id):
        """Does a GET request to /image/{productId}.

        This function allows logged in user to get image list for the existing
        product

        Args:
            product_id (string): ID of the property

        Returns:
            GetimagelistbyproductID: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/image/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetimagelistbyproductID.from_dictionary)

    def deleteallimagesperproperty(self,
                                   content_type,
                                   product_id):
        """Does a DELETE request to /image/{productId}.

        This function allows logged in user to delete images.

        Args:
            content_type (string): TODO: type description here. Example: 
            product_id (string): ID of property for which you want to delete
                all images

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/image/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def deletelistofimages(self,
                           content_type,
                           body):
        """Does a DELETE request to /image.

        This function allows the logged in user to delete image(s) from the
        existing product.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (DeletelistofimagesRequest): TODO: type description here.
                Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/image'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ManualPolicies(object):

    """Implementation of the 'ManualPolicies' model.

    TODO: type model description here.

    Attributes:
        charge_value (int): Percentage or flat value which will be charged in
            case of cancellation
        before_days (int): Days before check-in when cancellation policy will
            be charged
        cancellation_fee (float): Cancellation transaction fee - additional
            fee on cancellation

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "charge_value":'chargeValue',
        "before_days":'beforeDays',
        "cancellation_fee":'cancellationFee'
    }

    def __init__(self,
                 charge_value=None,
                 before_days=None,
                 cancellation_fee=None):
        """Constructor for the ManualPolicies class"""

        # Initialize members of the class
        self.charge_value = charge_value
        self.before_days = before_days
        self.cancellation_fee = cancellation_fee


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        charge_value = dictionary.get('chargeValue')
        before_days = dictionary.get('beforeDays')
        cancellation_fee = dictionary.get('cancellationFee')

        # Return an object of this model
        return cls(charge_value,
                   before_days,
                   cancellation_fee)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.decorators import lazy_property
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.product_controller import ProductController
from apimaticcalculatorlatest.controllers.los_pricing_controller import LOSPricingController
from apimaticcalculatorlatest.controllers.messaging_controller import MessagingController
from apimaticcalculatorlatest.controllers.property_managers_controller import PropertyManagersController
from apimaticcalculatorlatest.controllers.request_to_book_controller import RequestToBookController
from apimaticcalculatorlatest.controllers.images_controller import ImagesController
from apimaticcalculatorlatest.controllers.fee_and_tax_mandatory_at_the_property_level_controller import FeeAndTaxMandatoryAtThePropertyLevelController
from apimaticcalculatorlatest.controllers.yields_controller import YieldsController
from apimaticcalculatorlatest.controllers.fee_and_tax_controller import FeeAndTaxController
from apimaticcalculatorlatest.controllers.validation_controller import ValidationController
from apimaticcalculatorlatest.controllers.push_notification_controller import PushNotificationController
from apimaticcalculatorlatest.controllers.rates_and_availability_controller import RatesAndAvailabilityController
from apimaticcalculatorlatest.controllers.reservation_notifications_controller import ReservationNotificationsController
from apimaticcalculatorlatest.controllers.testing_of_message_api_calls_controller import TestingOfMessageAPICallsController
from apimaticcalculatorlatest.controllers.authorization_controller import AuthorizationController


class ApimaticcalculatorlatestClient(object):

    config = Configuration

    @lazy_property
    def product(self):
        return ProductController()

    @lazy_property
    def los_pricing(self):
        return LOSPricingController()

    @lazy_property
    def messaging(self):
        return MessagingController()

    @lazy_property
    def property_managers(self):
        return PropertyManagersController()

    @lazy_property
    def request_to_book(self):
        return RequestToBookController()

    @lazy_property
    def images(self):
        return ImagesController()

    @lazy_property
    def fee_and_tax_mandatory_at_the_property_level(self):
        return FeeAndTaxMandatoryAtThePropertyLevelController()

    @lazy_property
    def yields(self):
        return YieldsController()

    @lazy_property
    def fee_and_tax(self):
        return FeeAndTaxController()

    @lazy_property
    def validation(self):
        return ValidationController()

    @lazy_property
    def push_notification(self):
        return PushNotificationController()

    @lazy_property
    def rates_and_availability(self):
        return RatesAndAvailabilityController()

    @lazy_property
    def reservation_notifications(self):
        return ReservationNotificationsController()

    @lazy_property
    def testing_of_message_api_calls(self):
        return TestingOfMessageAPICallsController()

    @lazy_property
    def authorization(self):
        return AuthorizationController()


    def __init__(self,
                 jwt=None):
        if jwt is not None:
            Configuration.jwt = jwt




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.payment_policy
import apimaticcalculatorlatest.models.cancellation_policy
import apimaticcalculatorlatest.models.fee_tax_mandatory

class Policies(object):

    """Implementation of the 'Policies' model.

    TODO: type model description here.

    Attributes:
        payment_policy (PaymentPolicy): TODO: type description here.
        cancellation_policy (CancellationPolicy): TODO: type description
            here.
        fee_tax_mandatory (FeeTaxMandatory): TODO: type description here.
        terms (string): Full URL to PM terms and conditions
        check_in_time (string): Time of Check in (HH:MM:SS)
        check_out_time (string): Time of Check out (HH:MM:SS)
        lead_time (int): Minimum number of days before check-in for which
            reservation is allowed to be booked. Allowed values are 0-7.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_policy":'paymentPolicy',
        "cancellation_policy":'cancellationPolicy',
        "fee_tax_mandatory":'feeTaxMandatory',
        "terms":'terms',
        "check_in_time":'checkInTime',
        "check_out_time":'checkOutTime',
        "lead_time":'leadTime'
    }

    def __init__(self,
                 payment_policy=None,
                 cancellation_policy=None,
                 fee_tax_mandatory=None,
                 terms=None,
                 check_in_time=None,
                 check_out_time=None,
                 lead_time=None):
        """Constructor for the Policies class"""

        # Initialize members of the class
        self.payment_policy = payment_policy
        self.cancellation_policy = cancellation_policy
        self.fee_tax_mandatory = fee_tax_mandatory
        self.terms = terms
        self.check_in_time = check_in_time
        self.check_out_time = check_out_time
        self.lead_time = lead_time


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_policy = apimaticcalculatorlatest.models.payment_policy.PaymentPolicy.from_dictionary(dictionary.get('paymentPolicy')) if dictionary.get('paymentPolicy') else None
        cancellation_policy = apimaticcalculatorlatest.models.cancellation_policy.CancellationPolicy.from_dictionary(dictionary.get('cancellationPolicy')) if dictionary.get('cancellationPolicy') else None
        fee_tax_mandatory = apimaticcalculatorlatest.models.fee_tax_mandatory.FeeTaxMandatory.from_dictionary(dictionary.get('feeTaxMandatory')) if dictionary.get('feeTaxMandatory') else None
        terms = dictionary.get('terms')
        check_in_time = dictionary.get('checkInTime')
        check_out_time = dictionary.get('checkOutTime')
        lead_time = dictionary.get('leadTime')

        # Return an object of this model
        return cls(payment_policy,
                   cancellation_policy,
                   fee_tax_mandatory,
                   terms,
                   check_in_time,
                   check_out_time,
                   lead_time)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.rates_availabilityresponse import RatesAvailabilityresponse

class RatesAndAvailabilityController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def getratesandavailabilityproduct_id(self,
                                          content_type,
                                          product_id):
        """Does a GET request to /ra/{productId}.

        This function allows logged in users to get rates and availability for
        the specific product.
        Every API call in this section should be with PM credentials.

        Args:
            content_type (string): TODO: type description here. Example: 
            product_id (string): ID of the property

        Returns:
            RatesAvailabilityresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/ra/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, RatesAvailabilityresponse.from_dictionary)

    def createandupdateratesandavailability(self,
                                            content_type,
                                            body):
        """Does a POST request to /ra.

        Create and update calls are the same. When data is sent, if the data
        already exists in BookingPal - that data will be updated. Otherwise it
        will be created (inserted). If you want to update data for some
        period, you should just send data for these dates. All other data (for
        other dates) will remain untouched. This allows you to update only
        changed periods and we will not delete previously sent data for other
        periods.
        In the case of a first data push, all data for one property should be
        sent in one request.  When making updates or changes to existing data,
        then all changed data should be sent in one request.
        Note: if property is set to use LOS rates (supportedLosRates) - only
        field leadTime, array availableCount and availability can be updated
        in this API call (for MLT property). For SGL property only leadTime
        and availability can be updated. This API call can not be used for OWN
        properties.
        Important: Maximum allowed end date in any data type is 3 years in
        future.
        Every API call in this section should be with PM credentials.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateandupdateratesandavailabilityRequest): TODO: type
                description here. Example: 

        Returns:
            RatesAvailabilityresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/ra'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, RatesAvailabilityresponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeEntityTypeEnum(object):

    """Implementation of the 'FeeEntityTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        MANDATORY: TODO: type description here.
        OPTIONAL: TODO: type description here.
        MANDATORY_PAL: TODO: type description here.

    """

    MANDATORY = 'MANDATORY'

    OPTIONAL = 'OPTIONAL'

    MANDATORY_PAL = 'MANDATORY_PAL'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeTypeEnum(object):

    """Implementation of the 'FeeTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        GENERAL: TODO: type description here.
        PET_FEE: TODO: type description here.
        DEPOSIT: TODO: type description here.

    """

    GENERAL = 'GENERAL'

    PET_FEE = 'PET_FEE'

    DEPOSIT = 'DEPOSIT'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class PaymentGateways(object):

    """Implementation of the 'PaymentGateways' model.

    TODO: type model description here.

    Attributes:
        payment_gateways_type (PaymentGatewaysTypeEnum): TODO: type
            description here.
        user (string): Value necessary for accessing payment gateway, values
            are different per payment gateway: PAYPAL - Client ID
            AUTHORIZE_NET - User ID BRIDGE_PAY - Username PAY_BOX - Site
            number DIBS - Login O_GONE - User ID DOC_DATA - ID PAY_GATE - ID 
            Note: This value will not be returned in response.
        secret (string): Value necessary for accessing payment gateway, values
            are different per payment gateway: PAYPAL - Secret AUTHORIZE_NET -
            Transaction Key BRIDGE_PAY - Password  PAY_BOX - Rank number DIBS
            - Password O_GONE - Password  DOC_DATA - Password PAY_GATE -
            Password  Note: This value will not be returned in response.
        additional_field_1 (string): Additional value necessary for accessing
            some payment gateways, values are different per payment gateway:
            BRIDGE_PAY - Merchant Number PAY_BOX - An identifier DIBS -
            Merchant ID O_GONE - PSP ID  Note: This value will not be returned
            in response.
        additional_field_2 (string): Additional value necessary for accessing
            some payment gateways, values are different per payment gateway:
            BRIDGE_PAY - Merchant Number PAY_BOX - An identifier DIBS -
            Merchant ID O_GONE - PSP ID  Note: This value will not be returned
            in response.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_gateways_type":'paymentGatewaysType',
        "user":'user',
        "secret":'secret',
        "additional_field_1":'additionalField1',
        "additional_field_2":'additionalField2'
    }

    def __init__(self,
                 payment_gateways_type=None,
                 user=None,
                 secret=None,
                 additional_field_1=None,
                 additional_field_2=None):
        """Constructor for the PaymentGateways class"""

        # Initialize members of the class
        self.payment_gateways_type = payment_gateways_type
        self.user = user
        self.secret = secret
        self.additional_field_1 = additional_field_1
        self.additional_field_2 = additional_field_2


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_gateways_type = dictionary.get('paymentGatewaysType')
        user = dictionary.get('user')
        secret = dictionary.get('secret')
        additional_field_1 = dictionary.get('additionalField1')
        additional_field_2 = dictionary.get('additionalField2')

        # Return an object of this model
        return cls(payment_gateways_type,
                   user,
                   secret,
                   additional_field_1,
                   additional_field_2)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservationCommissionsNotificationModel(object):

    """Implementation of the 'ReservationCommissionsNotificationModel' model.

    TODO: type model description here.

    Attributes:
        channel_commission (float): Channel commission
        bp_commission (float): BookingPal commission

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "channel_commission":'channelCommission',
        "bp_commission":'bpCommission'
    }

    def __init__(self,
                 channel_commission=None,
                 bp_commission=None):
        """Constructor for the ReservationCommissionsNotificationModel class"""

        # Initialize members of the class
        self.channel_commission = channel_commission
        self.bp_commission = bp_commission


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        channel_commission = dictionary.get('channelCommission')
        bp_commission = dictionary.get('bpCommission')

        # Return an object of this model
        return cls(channel_commission,
                   bp_commission)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CreditCardTypeEnum(object):

    """Implementation of the 'CreditCardTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        TRANSMIT: TODO: type description here.
        POST: TODO: type description here.

    """

    TRANSMIT = 'TRANSMIT'

    POST = 'POST'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class SplitPayment(object):

    """Implementation of the 'SplitPayment' model.

    TODO: type model description here.

    Attributes:
        deposit_type (DepositTypeEnum): First payment deposit type.
        value (float): First payment value
        second_payment_days (int): Number of days before check-in when second
            payment is required.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "deposit_type":'depositType',
        "value":'value',
        "second_payment_days":'secondPaymentDays'
    }

    def __init__(self,
                 deposit_type=None,
                 value=None,
                 second_payment_days=None):
        """Constructor for the SplitPayment class"""

        # Initialize members of the class
        self.deposit_type = deposit_type
        self.value = value
        self.second_payment_days = second_payment_days


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        deposit_type = dictionary.get('depositType')
        value = dictionary.get('value')
        second_payment_days = dictionary.get('secondPaymentDays')

        # Return an object of this model
        return cls(deposit_type,
                   value,
                   second_payment_days)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TypeEnum(object):

    """Implementation of the 'TypeEnum' enum.

    Cancellation policy type. [FULLY_REFUNDABLE,NON_REFUNDABLE,MANUAL]

    Attributes:
        FULLY_REFUNDABLE: TODO: type description here.
        NON_REFUNDABLE: TODO: type description here.
        MANUAL: TODO: type description here.

    """

    FULLY_REFUNDABLE = 'FULLY_REFUNDABLE'

    NON_REFUNDABLE = 'NON_REFUNDABLE'

    MANUAL = 'MANUAL'




# -*- coding: utf-8 -*-

import sys
from setuptools import setup, find_packages

if sys.version_info[0] < 3:
    with open("README.md", "r") as fh:
        long_description = fh.read()
else:
    with open("README.md", "r", encoding="utf-8") as fh:
        long_description = fh.read()

setup(
    name='apimaticcalculatorlatest',
    version='4.0.0',
    description='Python client library for Channel Management API',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='APIMatic SDK Generator',
    author_email='support@apimatic.io',
    url='https://apimatic.io',
    packages=find_packages(),
    install_requires=[
        'requests>=2.9.1, <3.0',
        'jsonpickle>=0.7.1, <1.0',
        'cachecontrol>=0.11.7, <1.0',
        'python-dateutil>=2.5.3, <3.0'
    ]
)


# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class LosRate(object):

    """Implementation of the 'LosRate' model.

    Model for LOS (Length of stay) rates

    Attributes:
        check_in_date (date): Check-in Date. Date should be in format
            "yyyy-MM-dd"
        max_guests (int): Max guests for check in date
        los_value (list of float): List rates value per day. First value is
            for reservation for 1 day. Secoon. If you do not support booking
            for some specific number of days, set value 0 for that element in
            array.nd value is for reservation for 2 days, and so on. If you do
            not support booking for some specific number of days, set value 0
            for that element in array.
        currency (string): Currency for rates. It will be visiable only in GET
            response. You should not set this field in request since we will
            use product currency for every rate.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "check_in_date":'checkInDate',
        "max_guests":'maxGuests',
        "los_value":'losValue',
        "currency":'currency'
    }

    def __init__(self,
                 check_in_date=None,
                 max_guests=None,
                 los_value=None,
                 currency=None):
        """Constructor for the LosRate class"""

        # Initialize members of the class
        self.check_in_date = check_in_date
        self.max_guests = max_guests
        self.los_value = los_value
        self.currency = currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        check_in_date = dateutil.parser.parse(dictionary.get('checkInDate')).date() if dictionary.get('checkInDate') else None
        max_guests = dictionary.get('maxGuests')
        los_value = dictionary.get('losValue')
        currency = dictionary.get('currency')

        # Return an object of this model
        return cls(check_in_date,
                   max_guests,
                   los_value,
                   currency)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.fee_tax_response import FeeTaxResponse

class FeeAndTaxController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def getfeeandtaxlistbyproduct_id(self,
                                     product_id):
        """Does a GET request to /taxfee/{productId}.

        This function allows the logged in user to get a fee list for the
        specific product.

        Args:
            product_id (string): ID of the property

        Returns:
            FeeTaxResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/taxfee/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, FeeTaxResponse.from_dictionary)

    def createfeeandtax(self,
                        content_type,
                        body):
        """Does a POST request to /taxfee.

        This function allows the logged in user to set fees (i.e. cleaning
        fee, damage waiver, extra bed, extra person etc.) and taxes for the
        specific product. Here, you always need to send all fees and taxes for
        one property. All fees or taxes which were in our system for that
        property and which are not in the new request will be deleted. Taxes
        in the BookingPal system will always have percent value. 
        If you want to delete all fees and/or taxes for one property (if you
        do not have fees and taxes in your system for one property) send an
        empty list of fees and.or taxes. In short when you use this request
        you need to always send us a full list of fees and taxes per property,
        since we will do a full update.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreatefeeandtaxRequest): TODO: type description here.
                Example: 

        Returns:
            FeeTaxResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/taxfee'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, FeeTaxResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class AvailabilityModel(object):

    """Implementation of the 'AvailabilityModel' model.

    TODO: type model description here.

    Attributes:
        begin_date (date): Beginning date of date range for which availability
            is applied. Date should be in format "yyyy-MM-dd"
        end_date (date): End date of date range for which availability is
            applied. Additional clarification: If you have reservation from
            2020/08/05 - 2020/08/09, so checkout is on 2020/08/09 - you should
            send end date 2020/08/08, since 2020/08/09 is actually open for
            new reservation. Date should be in format "yyyy-MM-dd"
        availability (bool): Determines if the dates are available or not. Our
            system saves only not available dates, so it is enough that you
            sent only not available dates. But if you want to open dates that
            you previously sent that are not available, you need to send that
            these dates are available over API.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "begin_date":'beginDate',
        "end_date":'endDate',
        "availability":'availability'
    }

    def __init__(self,
                 begin_date=None,
                 end_date=None,
                 availability=None):
        """Constructor for the AvailabilityModel class"""

        # Initialize members of the class
        self.begin_date = begin_date
        self.end_date = end_date
        self.availability = availability


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        begin_date = dateutil.parser.parse(dictionary.get('beginDate')).date() if dictionary.get('beginDate') else None
        end_date = dateutil.parser.parse(dictionary.get('endDate')).date() if dictionary.get('endDate') else None
        availability = dictionary.get('availability')

        # Return an object of this model
        return cls(begin_date,
                   end_date,
                   availability)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.rates_availability

class RatesAvailabilityresponse(object):

    """Implementation of the 'RatesAvailabilityresponse' model.

    Rates Availability response

    Attributes:
        message (string): text info message
        error_message (list of string): List of error messages
        is_error (bool): Is error (default = false)
        code (string): Code of message
        data (list of RatesAvailability): List of models. This is a deprecated
            field. It will be removed in version 3.3. (This is only for Create
            and update requests, so you will not get this data in response).
            On GET request you will get data here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "message":'message',
        "error_message":'errorMessage',
        "is_error":'is_error',
        "code":'code',
        "data":'data'
    }

    def __init__(self,
                 message=None,
                 error_message=None,
                 is_error=None,
                 code=None,
                 data=None):
        """Constructor for the RatesAvailabilityresponse class"""

        # Initialize members of the class
        self.message = message
        self.error_message = error_message
        self.is_error = is_error
        self.code = code
        self.data = data


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        message = dictionary.get('message')
        error_message = dictionary.get('errorMessage')
        is_error = dictionary.get('is_error')
        code = dictionary.get('code')
        data = None
        if dictionary.get('data') != None:
            data = list()
            for structure in dictionary.get('data'):
                data.append(apimaticcalculatorlatest.models.rates_availability.RatesAvailability.from_dictionary(structure))

        # Return an object of this model
        return cls(message,
                   error_message,
                   is_error,
                   code,
                   data)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequestToBookTypeEnum(object):

    """Implementation of the 'RequestToBookTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ACCEPT: TODO: type description here.
        DENY: TODO: type description here.

    """

    ACCEPT = 'ACCEPT'

    DENY = 'DENY'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.company_details
import apimaticcalculatorlatest.models.policies
import apimaticcalculatorlatest.models.payment

class Company(object):

    """Implementation of the 'Company' model.

    Company model

    Attributes:
        company_details (CompanyDetails): TODO: type description here.
        policies (Policies): TODO: type description here.
        payment (Payment): TODO: type description here.
        id (int): Supplier id. Not expected in any requests. Will be only in
            responses.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "company_details":'companyDetails',
        "policies":'policies',
        "payment":'payment',
        "id":'id'
    }

    def __init__(self,
                 company_details=None,
                 policies=None,
                 payment=None,
                 id=None):
        """Constructor for the Company class"""

        # Initialize members of the class
        self.company_details = company_details
        self.policies = policies
        self.payment = payment
        self.id = id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        company_details = apimaticcalculatorlatest.models.company_details.CompanyDetails.from_dictionary(dictionary.get('companyDetails')) if dictionary.get('companyDetails') else None
        policies = apimaticcalculatorlatest.models.policies.Policies.from_dictionary(dictionary.get('policies')) if dictionary.get('policies') else None
        payment = apimaticcalculatorlatest.models.payment.Payment.from_dictionary(dictionary.get('payment')) if dictionary.get('payment') else None
        id = dictionary.get('id')

        # Return an object of this model
        return cls(company_details,
                   policies,
                   payment,
                   id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class PMs(object):

    """Implementation of the 'PMs' model.

    Property Manager model

    Attributes:
        id (int): ID of the property manager
        name (string): Name of the property manager’s company
        extra_name (string): Contact person
        email_address (string): Email of the property manager

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "name":'name',
        "extra_name":'extraName',
        "email_address":'emailAddress'
    }

    def __init__(self,
                 id=None,
                 name=None,
                 extra_name=None,
                 email_address=None):
        """Constructor for the PMs class"""

        # Initialize members of the class
        self.id = id
        self.name = name
        self.extra_name = extra_name
        self.email_address = email_address


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        name = dictionary.get('name')
        extra_name = dictionary.get('extraName')
        email_address = dictionary.get('emailAddress')

        # Return an object of this model
        return cls(id,
                   name,
                   extra_name,
                   email_address)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ImageTagsEnum(object):

    """Implementation of the 'ImageTagsEnum' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.
        ENUM_5: TODO: type description here.
        ENUM_6: TODO: type description here.
        ENUM_7: TODO: type description here.
        ENUM_8: TODO: type description here.
        ENUM_10: TODO: type description here.
        ENUM_43: TODO: type description here.
        ENUM_11: TODO: type description here.
        ENUM_13: TODO: type description here.
        ENUM_14: TODO: type description here.
        ENUM_37: TODO: type description here.
        ENUM_41: TODO: type description here.
        ENUM_42: TODO: type description here.
        ENUM_50: TODO: type description here.
        ENUM_55: TODO: type description here.
        ENUM_61: TODO: type description here.
        ENUM_70: TODO: type description here.
        ENUM_74: TODO: type description here.
        ENUM_81: TODO: type description here.
        ENUM_82: TODO: type description here.
        ENUM_87: TODO: type description here.
        ENUM_89: TODO: type description here.
        ENUM_90: TODO: type description here.
        ENUM_94: TODO: type description here.
        ENUM_95: TODO: type description here.
        ENUM_96: TODO: type description here.
        ENUM_97: TODO: type description here.
        ENUM_100: TODO: type description here.
        ENUM_102: TODO: type description here.
        ENUM_103: TODO: type description here.
        ENUM_104: TODO: type description here.
        ENUM_106: TODO: type description here.
        ENUM_107: TODO: type description here.
        ENUM_141: TODO: type description here.
        ENUM_108: TODO: type description here.
        ENUM_112: TODO: type description here.
        ENUM_113: TODO: type description here.
        ENUM_114: TODO: type description here.
        ENUM_115: TODO: type description here.
        ENUM_116: TODO: type description here.
        ENUM_124: TODO: type description here.
        ENUM_125: TODO: type description here.
        ENUM_128: TODO: type description here.
        ENUM_131: TODO: type description here.
        ENUM_137: TODO: type description here.
        ENUM_133: TODO: type description here.
        ENUM_134: TODO: type description here.
        ENUM_143: TODO: type description here.
        ENUM_153: TODO: type description here.
        ENUM_154: TODO: type description here.
        ENUM_155: TODO: type description here.
        ENUM_156: TODO: type description here.
        ENUM_157: TODO: type description here.
        ENUM_158: TODO: type description here.
        ENUM_159: TODO: type description here.
        ENUM_160: TODO: type description here.
        ENUM_161: TODO: type description here.
        ENUM_164: TODO: type description here.
        ENUM_165: TODO: type description here.
        ENUM_167: TODO: type description here.
        ENUM_172: TODO: type description here.
        ENUM_173: TODO: type description here.
        ENUM_177: TODO: type description here.
        ENUM_178: TODO: type description here.
        ENUM_179: TODO: type description here.
        ENUM_182: TODO: type description here.
        ENUM_183: TODO: type description here.
        ENUM_184: TODO: type description here.
        ENUM_185: TODO: type description here.
        ENUM_186: TODO: type description here.
        ENUM_187: TODO: type description here.
        ENUM_188: TODO: type description here.
        ENUM_189: TODO: type description here.
        ENUM_190: TODO: type description here.
        ENUM_191: TODO: type description here.
        ENUM_192: TODO: type description here.
        ENUM_193: TODO: type description here.
        ENUM_194: TODO: type description here.
        ENUM_197: TODO: type description here.
        ENUM_198: TODO: type description here.
        ENUM_199: TODO: type description here.
        ENUM_204: TODO: type description here.
        ENUM_205: TODO: type description here.
        ENUM_240: TODO: type description here.
        ENUM_241: TODO: type description here.
        ENUM_242: TODO: type description here.
        ENUM_245: TODO: type description here.
        ENUM_246: TODO: type description here.
        ENUM_247: TODO: type description here.
        ENUM_248: TODO: type description here.
        ENUM_249: TODO: type description here.
        ENUM_250: TODO: type description here.
        ENUM_251: TODO: type description here.
        ENUM_252: TODO: type description here.
        ENUM_253: TODO: type description here.
        ENUM_254: TODO: type description here.
        ENUM_255: TODO: type description here.
        ENUM_256: TODO: type description here.
        ENUM_257: TODO: type description here.
        ENUM_258: TODO: type description here.
        ENUM_259: TODO: type description here.
        ENUM_260: TODO: type description here.
        ENUM_261: TODO: type description here.
        ENUM_262: TODO: type description here.
        ENUM_263: TODO: type description here.
        ENUM_264: TODO: type description here.
        ENUM_265: TODO: type description here.
        ENUM_266: TODO: type description here.
        ENUM_267: TODO: type description here.
        ENUM_268: TODO: type description here.
        ENUM_269: TODO: type description here.
        ENUM_270: TODO: type description here.
        ENUM_271: TODO: type description here.
        ENUM_272: TODO: type description here.
        ENUM_273: TODO: type description here.
        ENUM_274: TODO: type description here.
        ENUM_275: TODO: type description here.
        ENUM_276: TODO: type description here.
        ENUM_277: TODO: type description here.
        ENUM_278: TODO: type description here.
        ENUM_279: TODO: type description here.
        ENUM_280: TODO: type description here.
        ENUM_281: TODO: type description here.
        ENUM_282: TODO: type description here.
        ENUM_283: TODO: type description here.
        ENUM_284: TODO: type description here.
        ENUM_285: TODO: type description here.
        ENUM_286: TODO: type description here.
        ENUM_287: TODO: type description here.
        ENUM_288: TODO: type description here.
        ENUM_289: TODO: type description here.
        ENUM_290: TODO: type description here.
        ENUM_291: TODO: type description here.

    """

    ENUM_1 = 1

    ENUM_2 = 2

    ENUM_3 = 3

    ENUM_4 = 4

    ENUM_5 = 5

    ENUM_6 = 6

    ENUM_7 = 7

    ENUM_8 = 8

    ENUM_10 = 10

    ENUM_43 = 43

    ENUM_11 = 11

    ENUM_13 = 13

    ENUM_14 = 14

    ENUM_37 = 37

    ENUM_41 = 41

    ENUM_42 = 42

    ENUM_50 = 50

    ENUM_55 = 55

    ENUM_61 = 61

    ENUM_70 = 70

    ENUM_74 = 74

    ENUM_81 = 81

    ENUM_82 = 82

    ENUM_87 = 87

    ENUM_89 = 89

    ENUM_90 = 90

    ENUM_94 = 94

    ENUM_95 = 95

    ENUM_96 = 96

    ENUM_97 = 97

    ENUM_100 = 100

    ENUM_102 = 102

    ENUM_103 = 103

    ENUM_104 = 104

    ENUM_106 = 106

    ENUM_107 = 107

    ENUM_141 = 141

    ENUM_108 = 108

    ENUM_112 = 112

    ENUM_113 = 113

    ENUM_114 = 114

    ENUM_115 = 115

    ENUM_116 = 116

    ENUM_124 = 124

    ENUM_125 = 125

    ENUM_128 = 128

    ENUM_131 = 131

    ENUM_137 = 137

    ENUM_133 = 133

    ENUM_134 = 134

    ENUM_143 = 143

    ENUM_153 = 153

    ENUM_154 = 154

    ENUM_155 = 155

    ENUM_156 = 156

    ENUM_157 = 157

    ENUM_158 = 158

    ENUM_159 = 159

    ENUM_160 = 160

    ENUM_161 = 161

    ENUM_164 = 164

    ENUM_165 = 165

    ENUM_167 = 167

    ENUM_172 = 172

    ENUM_173 = 173

    ENUM_177 = 177

    ENUM_178 = 178

    ENUM_179 = 179

    ENUM_182 = 182

    ENUM_183 = 183

    ENUM_184 = 184

    ENUM_185 = 185

    ENUM_186 = 186

    ENUM_187 = 187

    ENUM_188 = 188

    ENUM_189 = 189

    ENUM_190 = 190

    ENUM_191 = 191

    ENUM_192 = 192

    ENUM_193 = 193

    ENUM_194 = 194

    ENUM_197 = 197

    ENUM_198 = 198

    ENUM_199 = 199

    ENUM_204 = 204

    ENUM_205 = 205

    ENUM_240 = 240

    ENUM_241 = 241

    ENUM_242 = 242

    ENUM_245 = 245

    ENUM_246 = 246

    ENUM_247 = 247

    ENUM_248 = 248

    ENUM_249 = 249

    ENUM_250 = 250

    ENUM_251 = 251

    ENUM_252 = 252

    ENUM_253 = 253

    ENUM_254 = 254

    ENUM_255 = 255

    ENUM_256 = 256

    ENUM_257 = 257

    ENUM_258 = 258

    ENUM_259 = 259

    ENUM_260 = 260

    ENUM_261 = 261

    ENUM_262 = 262

    ENUM_263 = 263

    ENUM_264 = 264

    ENUM_265 = 265

    ENUM_266 = 266

    ENUM_267 = 267

    ENUM_268 = 268

    ENUM_269 = 269

    ENUM_270 = 270

    ENUM_271 = 271

    ENUM_272 = 272

    ENUM_273 = 273

    ENUM_274 = 274

    ENUM_275 = 275

    ENUM_276 = 276

    ENUM_277 = 277

    ENUM_278 = 278

    ENUM_279 = 279

    ENUM_280 = 280

    ENUM_281 = 281

    ENUM_282 = 282

    ENUM_283 = 283

    ENUM_284 = 284

    ENUM_285 = 285

    ENUM_286 = 286

    ENUM_287 = 287

    ENUM_288 = 288

    ENUM_289 = 289

    ENUM_290 = 290

    ENUM_291 = 291




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AmenityTypesEnum(object):

    """Implementation of the 'AmenityTypesEnum' enum.

    TODO: type enum description here.

    Attributes:
        ACC111: TODO: type description here.
        ACC112: TODO: type description here.
        ACC113: TODO: type description here.
        ACC114: TODO: type description here.
        ACC115: TODO: type description here.
        ACC116: TODO: type description here.
        ACC117: TODO: type description here.
        ACC118: TODO: type description here.
        ACC119: TODO: type description here.
        ACC120: TODO: type description here.
        ACC123: TODO: type description here.
        ACC14: TODO: type description here.
        ACC24: TODO: type description here.
        ACC25: TODO: type description here.
        ACC27: TODO: type description here.
        ACC28: TODO: type description here.
        ACC29: TODO: type description here.
        ACC31: TODO: type description here.
        ACC32: TODO: type description here.
        ACC33: TODO: type description here.
        ACC39: TODO: type description here.
        ACC40: TODO: type description here.
        ACC41: TODO: type description here.
        ACC42: TODO: type description here.
        ACC45: TODO: type description here.
        ACC47: TODO: type description here.
        ACC5: TODO: type description here.
        ACC50: TODO: type description here.
        ACC54: TODO: type description here.
        ACC55: TODO: type description here.
        ACC56: TODO: type description here.
        ACC57: TODO: type description here.
        ACC59: TODO: type description here.
        ACC73: TODO: type description here.
        ACC74: TODO: type description here.
        ACC82: TODO: type description here.
        ACC90: TODO: type description here.
        ACC95: TODO: type description here.
        HAC1: TODO: type description here.
        HAC101: TODO: type description here.
        HAC116: TODO: type description here.
        HAC122: TODO: type description here.
        HAC14: TODO: type description here.
        HAC149: TODO: type description here.
        HAC15: TODO: type description here.
        HAC154: TODO: type description here.
        HAC156: TODO: type description here.
        HAC157: TODO: type description here.
        HAC159: TODO: type description here.
        HAC16: TODO: type description here.
        HAC160: TODO: type description here.
        HAC165: TODO: type description here.
        HAC168: TODO: type description here.
        HAC173: TODO: type description here.
        HAC176: TODO: type description here.
        HAC186: TODO: type description here.
        HAC193: TODO: type description here.
        HAC195: TODO: type description here.
        HAC196: TODO: type description here.
        HAC197: TODO: type description here.
        HAC198: TODO: type description here.
        HAC202: TODO: type description here.
        HAC204: TODO: type description here.
        HAC21: TODO: type description here.
        HAC22: TODO: type description here.
        HAC226: TODO: type description here.
        HAC228: TODO: type description here.
        HAC230: TODO: type description here.
        HAC231: TODO: type description here.
        HAC232: TODO: type description here.
        HAC233: TODO: type description here.
        HAC234: TODO: type description here.
        HAC236: TODO: type description here.
        HAC237: TODO: type description here.
        HAC238: TODO: type description here.
        HAC239: TODO: type description here.
        HAC241: TODO: type description here.
        HAC242: TODO: type description here.
        HAC246: TODO: type description here.
        HAC25: TODO: type description here.
        HAC254: TODO: type description here.
        HAC26: TODO: type description here.
        HAC262: TODO: type description here.
        HAC265: TODO: type description here.
        HAC269: TODO: type description here.
        HAC272: TODO: type description here.
        HAC273: TODO: type description here.
        HAC280: TODO: type description here.
        HAC282: TODO: type description here.
        HAC283: TODO: type description here.
        HAC29: TODO: type description here.
        HAC292: TODO: type description here.
        HAC301: TODO: type description here.
        HAC309: TODO: type description here.
        HAC310: TODO: type description here.
        HAC312: TODO: type description here.
        HAC316: TODO: type description here.
        HAC32: TODO: type description here.
        HAC327: TODO: type description here.
        HAC33: TODO: type description here.
        HAC334: TODO: type description here.
        HAC34: TODO: type description here.
        HAC342: TODO: type description here.
        HAC345: TODO: type description here.
        HAC348: TODO: type description here.
        HAC36: TODO: type description here.
        HAC37: TODO: type description here.
        HAC41: TODO: type description here.
        HAC42: TODO: type description here.
        HAC44: TODO: type description here.
        HAC45: TODO: type description here.
        HAC49: TODO: type description here.
        HAC5: TODO: type description here.
        HAC50: TODO: type description here.
        HAC5033: TODO: type description here.
        HAC51: TODO: type description here.
        HAC53: TODO: type description here.
        HAC54: TODO: type description here.
        HAC55: TODO: type description here.
        HAC60: TODO: type description here.
        HAC6002: TODO: type description here.
        HAC6008: TODO: type description here.
        HAC6010: TODO: type description here.
        HAC6013: TODO: type description here.
        HAC6014: TODO: type description here.
        HAC6019: TODO: type description here.
        HAC6020: TODO: type description here.
        HAC6024: TODO: type description here.
        HAC6025: TODO: type description here.
        HAC6026: TODO: type description here.
        HAC6027: TODO: type description here.
        HAC6028: TODO: type description here.
        HAC6029: TODO: type description here.
        HAC6030: TODO: type description here.
        HAC6031: TODO: type description here.
        HAC6032: TODO: type description here.
        HAC6033: TODO: type description here.
        HAC6034: TODO: type description here.
        HAC6035: TODO: type description here.
        HAC6036: TODO: type description here.
        HAC6037: TODO: type description here.
        HAC6038: TODO: type description here.
        HAC6039: TODO: type description here.
        HAC6040: TODO: type description here.
        HAC6041: TODO: type description here.
        HAC6042: TODO: type description here.
        HAC6043: TODO: type description here.
        HAC6044: TODO: type description here.
        HAC6045: TODO: type description here.
        HAC6046: TODO: type description here.
        HAC6047: TODO: type description here.
        HAC6048: TODO: type description here.
        HAC6049: TODO: type description here.
        HAC6050: TODO: type description here.
        HAC6051: TODO: type description here.
        HAC6052: TODO: type description here.
        HAC6053: TODO: type description here.
        HAC6054: TODO: type description here.
        HAC6055: TODO: type description here.
        HAC6056: TODO: type description here.
        HAC6057: TODO: type description here.
        HAC6058: TODO: type description here.
        HAC6059: TODO: type description here.
        HAC6060: TODO: type description here.
        HAC6061: TODO: type description here.
        HAC6062: TODO: type description here.
        HAC6063: TODO: type description here.
        HAC6064: TODO: type description here.
        HAC6065: TODO: type description here.
        HAC6066: TODO: type description here.
        HAC6067: TODO: type description here.
        HAC6068: TODO: type description here.
        HAC6069: TODO: type description here.
        HAC6070: TODO: type description here.
        HAC6072: TODO: type description here.
        HAC6073: TODO: type description here.
        HAC6074: TODO: type description here.
        HAC6075: TODO: type description here.
        HAC6076: TODO: type description here.
        HAC6077: TODO: type description here.
        HAC6078: TODO: type description here.
        HAC6079: TODO: type description here.
        HAC6080: TODO: type description here.
        HAC6081: TODO: type description here.
        HAC6082: TODO: type description here.
        HAC6084: TODO: type description here.
        HAC6085: TODO: type description here.
        HAC6086: TODO: type description here.
        HAC6087: TODO: type description here.
        HAC6088: TODO: type description here.
        HAC6089: TODO: type description here.
        HAC6090: TODO: type description here.
        HAC6091: TODO: type description here.
        HAC6092: TODO: type description here.
        HAC6093: TODO: type description here.
        HAC6095: TODO: type description here.
        HAC6096: TODO: type description here.
        HAC6097: TODO: type description here.
        HAC6098: TODO: type description here.
        HAC6099: TODO: type description here.
        HAC61: TODO: type description here.
        HAC6100: TODO: type description here.
        HAC6101: TODO: type description here.
        HAC6102: TODO: type description here.
        HAC6103: TODO: type description here.
        HAC6104: TODO: type description here.
        HAC6105: TODO: type description here.
        HAC6106: TODO: type description here.
        HAC6107: TODO: type description here.
        HAC6108: TODO: type description here.
        HAC6109: TODO: type description here.
        HAC6110: TODO: type description here.
        HAC6111: TODO: type description here.
        HAC6113: TODO: type description here.
        HAC6114: TODO: type description here.
        HAC6115: TODO: type description here.
        HAC6116: TODO: type description here.
        HAC6117: TODO: type description here.
        HAC6118: TODO: type description here.
        HAC6119: TODO: type description here.
        HAC6120: TODO: type description here.
        HAC6121: TODO: type description here.
        HAC6122: TODO: type description here.
        HAC6123: TODO: type description here.
        HAC6124: TODO: type description here.
        HAC6125: TODO: type description here.
        HAC6126: TODO: type description here.
        HAC6127: TODO: type description here.
        HAC6128: TODO: type description here.
        HAC6129: TODO: type description here.
        HAC6130: TODO: type description here.
        HAC6131: TODO: type description here.
        HAC6132: TODO: type description here.
        HAC6133: TODO: type description here.
        HAC6134: TODO: type description here.
        HAC6135: TODO: type description here.
        HAC6136: TODO: type description here.
        HAC6137: TODO: type description here.
        HAC6138: TODO: type description here.
        HAC62: TODO: type description here.
        HAC66: TODO: type description here.
        HAC7: TODO: type description here.
        HAC71: TODO: type description here.
        HAC76: TODO: type description here.
        HAC77: TODO: type description here.
        HAC78: TODO: type description here.
        HAC79: TODO: type description here.
        HAC8: TODO: type description here.
        HAC81: TODO: type description here.
        HAC83: TODO: type description here.
        HAC86: TODO: type description here.
        HAC9: TODO: type description here.
        HAC91: TODO: type description here.
        HAC94: TODO: type description here.
        HAC96: TODO: type description here.
        HAC97: TODO: type description here.
        HAC98: TODO: type description here.
        RMA1: TODO: type description here.
        RMA10: TODO: type description here.
        RMA100: TODO: type description here.
        RMA102: TODO: type description here.
        RMA103: TODO: type description here.
        RMA104: TODO: type description here.
        RMA105: TODO: type description here.
        RMA107: TODO: type description here.
        RMA108: TODO: type description here.
        RMA11: TODO: type description here.
        RMA111: TODO: type description here.
        RMA113: TODO: type description here.
        RMA115: TODO: type description here.
        RMA117: TODO: type description here.
        RMA119: TODO: type description here.
        RMA126: TODO: type description here.
        RMA127: TODO: type description here.
        RMA129: TODO: type description here.
        RMA13: TODO: type description here.
        RMA133: TODO: type description here.
        RMA135: TODO: type description here.
        RMA138: TODO: type description here.
        RMA139: TODO: type description here.
        RMA14: TODO: type description here.
        RMA141: TODO: type description here.
        RMA142: TODO: type description here.
        RMA143: TODO: type description here.
        RMA144: TODO: type description here.
        RMA146: TODO: type description here.
        RMA147: TODO: type description here.
        RMA149: TODO: type description here.
        RMA15: TODO: type description here.
        RMA151: TODO: type description here.
        RMA155: TODO: type description here.
        RMA157: TODO: type description here.
        RMA158: TODO: type description here.
        RMA16: TODO: type description here.
        RMA161: TODO: type description here.
        RMA162: TODO: type description here.
        RMA163: TODO: type description here.
        RMA164: TODO: type description here.
        RMA166: TODO: type description here.
        RMA167: TODO: type description here.
        RMA170: TODO: type description here.
        RMA175: TODO: type description here.
        RMA18: TODO: type description here.
        RMA186: TODO: type description here.
        RMA19: TODO: type description here.
        RMA190: TODO: type description here.
        RMA191: TODO: type description here.
        RMA192: TODO: type description here.
        RMA193: TODO: type description here.
        RMA194: TODO: type description here.
        RMA195: TODO: type description here.
        RMA2: TODO: type description here.
        RMA20: TODO: type description here.
        RMA200: TODO: type description here.
        RMA201: TODO: type description here.
        RMA203: TODO: type description here.
        RMA204: TODO: type description here.
        RMA205: TODO: type description here.
        RMA207: TODO: type description here.
        RMA21: TODO: type description here.
        RMA210: TODO: type description here.
        RMA214: TODO: type description here.
        RMA217: TODO: type description here.
        RMA218: TODO: type description here.
        RMA22: TODO: type description here.
        RMA220: TODO: type description here.
        RMA223: TODO: type description here.
        RMA224: TODO: type description here.
        RMA227: TODO: type description here.
        RMA228: TODO: type description here.
        RMA230: TODO: type description here.
        RMA231: TODO: type description here.
        RMA234: TODO: type description here.
        RMA242: TODO: type description here.
        RMA245: TODO: type description here.
        RMA246: TODO: type description here.
        RMA25: TODO: type description here.
        RMA251: TODO: type description here.
        RMA254: TODO: type description here.
        RMA256: TODO: type description here.
        RMA258: TODO: type description here.
        RMA259: TODO: type description here.
        RMA26: TODO: type description here.
        RMA260: TODO: type description here.
        RMA262: TODO: type description here.
        RMA265: TODO: type description here.
        RMA268: TODO: type description here.
        RMA269: TODO: type description here.
        RMA270: TODO: type description here.
        RMA271: TODO: type description here.
        RMA273: TODO: type description here.
        RMA276: TODO: type description here.
        RMA279: TODO: type description here.
        RMA28: TODO: type description here.
        RMA280: TODO: type description here.
        RMA29: TODO: type description here.
        RMA3: TODO: type description here.
        RMA32: TODO: type description here.
        RMA33: TODO: type description here.
        RMA38: TODO: type description here.
        RMA41: TODO: type description here.
        RMA45: TODO: type description here.
        RMA46: TODO: type description here.
        RMA47: TODO: type description here.
        RMA49: TODO: type description here.
        RMA5: TODO: type description here.
        RMA50: TODO: type description here.
        RMA5005: TODO: type description here.
        RMA5020: TODO: type description here.
        RMA5085: TODO: type description here.
        RMA5086: TODO: type description here.
        RMA5091: TODO: type description here.
        RMA5126: TODO: type description here.
        RMA5145: TODO: type description here.
        RMA55: TODO: type description here.
        RMA56: TODO: type description here.
        RMA57: TODO: type description here.
        RMA58: TODO: type description here.
        RMA59: TODO: type description here.
        RMA6: TODO: type description here.
        RMA60: TODO: type description here.
        RMA6001: TODO: type description here.
        RMA6003: TODO: type description here.
        RMA6004: TODO: type description here.
        RMA6005: TODO: type description here.
        RMA6010: TODO: type description here.
        RMA6012: TODO: type description here.
        RMA6013: TODO: type description here.
        RMA6017: TODO: type description here.
        RMA6018: TODO: type description here.
        RMA6021: TODO: type description here.
        RMA6027: TODO: type description here.
        RMA6028: TODO: type description here.
        RMA6029: TODO: type description here.
        RMA6030: TODO: type description here.
        RMA6031: TODO: type description here.
        RMA6032: TODO: type description here.
        RMA6033: TODO: type description here.
        RMA6034: TODO: type description here.
        RMA6035: TODO: type description here.
        RMA6036: TODO: type description here.
        RMA6037: TODO: type description here.
        RMA6038: TODO: type description here.
        RMA6039: TODO: type description here.
        RMA6040: TODO: type description here.
        RMA6042: TODO: type description here.
        RMA6045: TODO: type description here.
        RMA6046: TODO: type description here.
        RMA6051: TODO: type description here.
        RMA6052: TODO: type description here.
        RMA6053: TODO: type description here.
        RMA6054: TODO: type description here.
        RMA6055: TODO: type description here.
        RMA6056: TODO: type description here.
        RMA6057: TODO: type description here.
        RMA6058: TODO: type description here.
        RMA6059: TODO: type description here.
        RMA6060: TODO: type description here.
        RMA6061: TODO: type description here.
        RMA6062: TODO: type description here.
        RMA6063: TODO: type description here.
        RMA6064: TODO: type description here.
        RMA6065: TODO: type description here.
        RMA6066: TODO: type description here.
        RMA6067: TODO: type description here.
        RMA6068: TODO: type description here.
        RMA6071: TODO: type description here.
        RMA6072: TODO: type description here.
        RMA6073: TODO: type description here.
        RMA6074: TODO: type description here.
        RMA6075: TODO: type description here.
        RMA6076: TODO: type description here.
        RMA6077: TODO: type description here.
        RMA6078: TODO: type description here.
        RMA6079: TODO: type description here.
        RMA6080: TODO: type description here.
        RMA6081: TODO: type description here.
        RMA6082: TODO: type description here.
        RMA6083: TODO: type description here.
        RMA6084: TODO: type description here.
        RMA6085: TODO: type description here.
        RMA6086: TODO: type description here.
        RMA6087: TODO: type description here.
        RMA6088: TODO: type description here.
        RMA6089: TODO: type description here.
        RMA6090: TODO: type description here.
        RMA6091: TODO: type description here.
        RMA6092: TODO: type description here.
        RMA6093: TODO: type description here.
        RMA6094: TODO: type description here.
        RMA6095: TODO: type description here.
        RMA6096: TODO: type description here.
        RMA6097: TODO: type description here.
        RMA6098: TODO: type description here.
        RMA6099: TODO: type description here.
        RMA61: TODO: type description here.
        RMA6100: TODO: type description here.
        RMA6101: TODO: type description here.
        RMA6102: TODO: type description here.
        RMA6103: TODO: type description here.
        RMA6104: TODO: type description here.
        RMA6105: TODO: type description here.
        RMA6106: TODO: type description here.
        RMA6107: TODO: type description here.
        RMA6108: TODO: type description here.
        RMA6109: TODO: type description here.
        RMA6110: TODO: type description here.
        RMA6111: TODO: type description here.
        RMA6112: TODO: type description here.
        RMA6113: TODO: type description here.
        RMA6114: TODO: type description here.
        RMA6115: TODO: type description here.
        RMA6116: TODO: type description here.
        RMA6117: TODO: type description here.
        RMA6118: TODO: type description here.
        RMA6119: TODO: type description here.
        RMA6120: TODO: type description here.
        RMA6121: TODO: type description here.
        RMA6122: TODO: type description here.
        RMA6123: TODO: type description here.
        RMA6124: TODO: type description here.
        RMA6125: TODO: type description here.
        RMA6126: TODO: type description here.
        RMA6127: TODO: type description here.
        RMA6128: TODO: type description here.
        RMA6129: TODO: type description here.
        RMA6130: TODO: type description here.
        RMA6131: TODO: type description here.
        RMA6132: TODO: type description here.
        RMA6133: TODO: type description here.
        RMA6134: TODO: type description here.
        RMA6135: TODO: type description here.
        RMA6136: TODO: type description here.
        RMA6137: TODO: type description here.
        RMA6138: TODO: type description here.
        RMA6139: TODO: type description here.
        RMA6140: TODO: type description here.
        RMA6141: TODO: type description here.
        RMA6142: TODO: type description here.
        RMA6144: TODO: type description here.
        RMA6145: TODO: type description here.
        RMA6146: TODO: type description here.
        RMA6147: TODO: type description here.
        RMA6148: TODO: type description here.
        RMA6149: TODO: type description here.
        RMA6150: TODO: type description here.
        RMA6151: TODO: type description here.
        RMA6152: TODO: type description here.
        RMA6153: TODO: type description here.
        RMA6154: TODO: type description here.
        RMA6155: TODO: type description here.
        RMA6156: TODO: type description here.
        RMA6157: TODO: type description here.
        RMA6158: TODO: type description here.
        RMA63: TODO: type description here.
        RMA64: TODO: type description here.
        RMA67: TODO: type description here.
        RMA68: TODO: type description here.
        RMA69: TODO: type description here.
        RMA7: TODO: type description here.
        RMA72: TODO: type description here.
        RMA77: TODO: type description here.
        RMA78: TODO: type description here.
        RMA8: TODO: type description here.
        RMA80: TODO: type description here.
        RMA81: TODO: type description here.
        RMA85: TODO: type description here.
        RMA86: TODO: type description here.
        RMA88: TODO: type description here.
        RMA89: TODO: type description here.
        RMA9: TODO: type description here.
        RMA91: TODO: type description here.
        RMA92: TODO: type description here.
        RMA94: TODO: type description here.
        RMA97: TODO: type description here.
        RMA98: TODO: type description here.
        RMA99: TODO: type description here.
        RST101: TODO: type description here.
        RST104: TODO: type description here.
        RST105: TODO: type description here.
        RST108: TODO: type description here.
        RST111: TODO: type description here.
        RST112: TODO: type description here.
        RST116: TODO: type description here.
        RST117: TODO: type description here.
        RST120: TODO: type description here.
        RST123: TODO: type description here.
        RST127: TODO: type description here.
        RST129: TODO: type description here.
        RST13: TODO: type description here.
        RST133: TODO: type description here.
        RST134: TODO: type description here.
        RST137: TODO: type description here.
        RST14: TODO: type description here.
        RST149: TODO: type description here.
        RST151: TODO: type description here.
        RST156: TODO: type description here.
        RST157: TODO: type description here.
        RST160: TODO: type description here.
        RST161: TODO: type description here.
        RST169: TODO: type description here.
        RST170: TODO: type description here.
        RST171: TODO: type description here.
        RST172: TODO: type description here.
        RST173: TODO: type description here.
        RST174: TODO: type description here.
        RST175: TODO: type description here.
        RST176: TODO: type description here.
        RST177: TODO: type description here.
        RST178: TODO: type description here.
        RST179: TODO: type description here.
        RST180: TODO: type description here.
        RST181: TODO: type description here.
        RST182: TODO: type description here.
        RST183: TODO: type description here.
        RST184: TODO: type description here.
        RST185: TODO: type description here.
        RST186: TODO: type description here.
        RST187: TODO: type description here.
        RST20: TODO: type description here.
        RST25: TODO: type description here.
        RST34: TODO: type description here.
        RST35: TODO: type description here.
        RST4: TODO: type description here.
        RST5028: TODO: type description here.
        RST60: TODO: type description here.
        RST63: TODO: type description here.
        RST65: TODO: type description here.
        RST67: TODO: type description here.
        RST68: TODO: type description here.
        RST7: TODO: type description here.
        RST71: TODO: type description here.
        RST73: TODO: type description here.
        RST74: TODO: type description here.
        RST79: TODO: type description here.
        RST80: TODO: type description here.
        RST82: TODO: type description here.
        RST86: TODO: type description here.
        RST87: TODO: type description here.
        RST9: TODO: type description here.
        RST92: TODO: type description here.
        RST96: TODO: type description here.

    """

    ACC111 = 'ACC111'

    ACC112 = 'ACC112'

    ACC113 = 'ACC113'

    ACC114 = 'ACC114'

    ACC115 = 'ACC115'

    ACC116 = 'ACC116'

    ACC117 = 'ACC117'

    ACC118 = 'ACC118'

    ACC119 = 'ACC119'

    ACC120 = 'ACC120'

    ACC123 = 'ACC123'

    ACC14 = 'ACC14'

    ACC24 = 'ACC24'

    ACC25 = 'ACC25'

    ACC27 = 'ACC27'

    ACC28 = 'ACC28'

    ACC29 = 'ACC29'

    ACC31 = 'ACC31'

    ACC32 = 'ACC32'

    ACC33 = 'ACC33'

    ACC39 = 'ACC39'

    ACC40 = 'ACC40'

    ACC41 = 'ACC41'

    ACC42 = 'ACC42'

    ACC45 = 'ACC45'

    ACC47 = 'ACC47'

    ACC5 = 'ACC5'

    ACC50 = 'ACC50'

    ACC54 = 'ACC54'

    ACC55 = 'ACC55'

    ACC56 = 'ACC56'

    ACC57 = 'ACC57'

    ACC59 = 'ACC59'

    ACC73 = 'ACC73'

    ACC74 = 'ACC74'

    ACC82 = 'ACC82'

    ACC90 = 'ACC90'

    ACC95 = 'ACC95'

    HAC1 = 'HAC1'

    HAC101 = 'HAC101'

    HAC116 = 'HAC116'

    HAC122 = 'HAC122'

    HAC14 = 'HAC14'

    HAC149 = 'HAC149'

    HAC15 = 'HAC15'

    HAC154 = 'HAC154'

    HAC156 = 'HAC156'

    HAC157 = 'HAC157'

    HAC159 = 'HAC159'

    HAC16 = 'HAC16'

    HAC160 = 'HAC160'

    HAC165 = 'HAC165'

    HAC168 = 'HAC168'

    HAC173 = 'HAC173'

    HAC176 = 'HAC176'

    HAC186 = 'HAC186'

    HAC193 = 'HAC193'

    HAC195 = 'HAC195'

    HAC196 = 'HAC196'

    HAC197 = 'HAC197'

    HAC198 = 'HAC198'

    HAC202 = 'HAC202'

    HAC204 = 'HAC204'

    HAC21 = 'HAC21'

    HAC22 = 'HAC22'

    HAC226 = 'HAC226'

    HAC228 = 'HAC228'

    HAC230 = 'HAC230'

    HAC231 = 'HAC231'

    HAC232 = 'HAC232'

    HAC233 = 'HAC233'

    HAC234 = 'HAC234'

    HAC236 = 'HAC236'

    HAC237 = 'HAC237'

    HAC238 = 'HAC238'

    HAC239 = 'HAC239'

    HAC241 = 'HAC241'

    HAC242 = 'HAC242'

    HAC246 = 'HAC246'

    HAC25 = 'HAC25'

    HAC254 = 'HAC254'

    HAC26 = 'HAC26'

    HAC262 = 'HAC262'

    HAC265 = 'HAC265'

    HAC269 = 'HAC269'

    HAC272 = 'HAC272'

    HAC273 = 'HAC273'

    HAC280 = 'HAC280'

    HAC282 = 'HAC282'

    HAC283 = 'HAC283'

    HAC29 = 'HAC29'

    HAC292 = 'HAC292'

    HAC301 = 'HAC301'

    HAC309 = 'HAC309'

    HAC310 = 'HAC310'

    HAC312 = 'HAC312'

    HAC316 = 'HAC316'

    HAC32 = 'HAC32'

    HAC327 = 'HAC327'

    HAC33 = 'HAC33'

    HAC334 = 'HAC334'

    HAC34 = 'HAC34'

    HAC342 = 'HAC342'

    HAC345 = 'HAC345'

    HAC348 = 'HAC348'

    HAC36 = 'HAC36'

    HAC37 = 'HAC37'

    HAC41 = 'HAC41'

    HAC42 = 'HAC42'

    HAC44 = 'HAC44'

    HAC45 = 'HAC45'

    HAC49 = 'HAC49'

    HAC5 = 'HAC5'

    HAC50 = 'HAC50'

    HAC5033 = 'HAC5033'

    HAC51 = 'HAC51'

    HAC53 = 'HAC53'

    HAC54 = 'HAC54'

    HAC55 = 'HAC55'

    HAC60 = 'HAC60'

    HAC6002 = 'HAC6002'

    HAC6008 = 'HAC6008'

    HAC6010 = 'HAC6010'

    HAC6013 = 'HAC6013'

    HAC6014 = 'HAC6014'

    HAC6019 = 'HAC6019'

    HAC6020 = 'HAC6020'

    HAC6024 = 'HAC6024'

    HAC6025 = 'HAC6025'

    HAC6026 = 'HAC6026'

    HAC6027 = 'HAC6027'

    HAC6028 = 'HAC6028'

    HAC6029 = 'HAC6029'

    HAC6030 = 'HAC6030'

    HAC6031 = 'HAC6031'

    HAC6032 = 'HAC6032'

    HAC6033 = 'HAC6033'

    HAC6034 = 'HAC6034'

    HAC6035 = 'HAC6035'

    HAC6036 = 'HAC6036'

    HAC6037 = 'HAC6037'

    HAC6038 = 'HAC6038'

    HAC6039 = 'HAC6039'

    HAC6040 = 'HAC6040'

    HAC6041 = 'HAC6041'

    HAC6042 = 'HAC6042'

    HAC6043 = 'HAC6043'

    HAC6044 = 'HAC6044'

    HAC6045 = 'HAC6045'

    HAC6046 = 'HAC6046'

    HAC6047 = 'HAC6047'

    HAC6048 = 'HAC6048'

    HAC6049 = 'HAC6049'

    HAC6050 = 'HAC6050'

    HAC6051 = 'HAC6051'

    HAC6052 = 'HAC6052'

    HAC6053 = 'HAC6053'

    HAC6054 = 'HAC6054'

    HAC6055 = 'HAC6055'

    HAC6056 = 'HAC6056'

    HAC6057 = 'HAC6057'

    HAC6058 = 'HAC6058'

    HAC6059 = 'HAC6059'

    HAC6060 = 'HAC6060'

    HAC6061 = 'HAC6061'

    HAC6062 = 'HAC6062'

    HAC6063 = 'HAC6063'

    HAC6064 = 'HAC6064'

    HAC6065 = 'HAC6065'

    HAC6066 = 'HAC6066'

    HAC6067 = 'HAC6067'

    HAC6068 = 'HAC6068'

    HAC6069 = 'HAC6069'

    HAC6070 = 'HAC6070'

    HAC6072 = 'HAC6072'

    HAC6073 = 'HAC6073'

    HAC6074 = 'HAC6074'

    HAC6075 = 'HAC6075'

    HAC6076 = 'HAC6076'

    HAC6077 = 'HAC6077'

    HAC6078 = 'HAC6078'

    HAC6079 = 'HAC6079'

    HAC6080 = 'HAC6080'

    HAC6081 = 'HAC6081'

    HAC6082 = 'HAC6082'

    HAC6084 = 'HAC6084'

    HAC6085 = 'HAC6085'

    HAC6086 = 'HAC6086'

    HAC6087 = 'HAC6087'

    HAC6088 = 'HAC6088'

    HAC6089 = 'HAC6089'

    HAC6090 = 'HAC6090'

    HAC6091 = 'HAC6091'

    HAC6092 = 'HAC6092'

    HAC6093 = 'HAC6093'

    HAC6095 = 'HAC6095'

    HAC6096 = 'HAC6096'

    HAC6097 = 'HAC6097'

    HAC6098 = 'HAC6098'

    HAC6099 = 'HAC6099'

    HAC61 = 'HAC61'

    HAC6100 = 'HAC6100'

    HAC6101 = 'HAC6101'

    HAC6102 = 'HAC6102'

    HAC6103 = 'HAC6103'

    HAC6104 = 'HAC6104'

    HAC6105 = 'HAC6105'

    HAC6106 = 'HAC6106'

    HAC6107 = 'HAC6107'

    HAC6108 = 'HAC6108'

    HAC6109 = 'HAC6109'

    HAC6110 = 'HAC6110'

    HAC6111 = 'HAC6111'

    HAC6113 = 'HAC6113'

    HAC6114 = 'HAC6114'

    HAC6115 = 'HAC6115'

    HAC6116 = 'HAC6116'

    HAC6117 = 'HAC6117'

    HAC6118 = 'HAC6118'

    HAC6119 = 'HAC6119'

    HAC6120 = 'HAC6120'

    HAC6121 = 'HAC6121'

    HAC6122 = 'HAC6122'

    HAC6123 = 'HAC6123'

    HAC6124 = 'HAC6124'

    HAC6125 = 'HAC6125'

    HAC6126 = 'HAC6126'

    HAC6127 = 'HAC6127'

    HAC6128 = 'HAC6128'

    HAC6129 = 'HAC6129'

    HAC6130 = 'HAC6130'

    HAC6131 = 'HAC6131'

    HAC6132 = 'HAC6132'

    HAC6133 = 'HAC6133'

    HAC6134 = 'HAC6134'

    HAC6135 = 'HAC6135'

    HAC6136 = 'HAC6136'

    HAC6137 = 'HAC6137'

    HAC6138 = 'HAC6138'

    HAC62 = 'HAC62'

    HAC66 = 'HAC66'

    HAC7 = 'HAC7'

    HAC71 = 'HAC71'

    HAC76 = 'HAC76'

    HAC77 = 'HAC77'

    HAC78 = 'HAC78'

    HAC79 = 'HAC79'

    HAC8 = 'HAC8'

    HAC81 = 'HAC81'

    HAC83 = 'HAC83'

    HAC86 = 'HAC86'

    HAC9 = 'HAC9'

    HAC91 = 'HAC91'

    HAC94 = 'HAC94'

    HAC96 = 'HAC96'

    HAC97 = 'HAC97'

    HAC98 = 'HAC98'

    RMA1 = 'RMA1'

    RMA10 = 'RMA10'

    RMA100 = 'RMA100'

    RMA102 = 'RMA102'

    RMA103 = 'RMA103'

    RMA104 = 'RMA104'

    RMA105 = 'RMA105'

    RMA107 = 'RMA107'

    RMA108 = 'RMA108'

    RMA11 = 'RMA11'

    RMA111 = 'RMA111'

    RMA113 = 'RMA113'

    RMA115 = 'RMA115'

    RMA117 = 'RMA117'

    RMA119 = 'RMA119'

    RMA126 = 'RMA126'

    RMA127 = 'RMA127'

    RMA129 = 'RMA129'

    RMA13 = 'RMA13'

    RMA133 = 'RMA133'

    RMA135 = 'RMA135'

    RMA138 = 'RMA138'

    RMA139 = 'RMA139'

    RMA14 = 'RMA14'

    RMA141 = 'RMA141'

    RMA142 = 'RMA142'

    RMA143 = 'RMA143'

    RMA144 = 'RMA144'

    RMA146 = 'RMA146'

    RMA147 = 'RMA147'

    RMA149 = 'RMA149'

    RMA15 = 'RMA15'

    RMA151 = 'RMA151'

    RMA155 = 'RMA155'

    RMA157 = 'RMA157'

    RMA158 = 'RMA158'

    RMA16 = 'RMA16'

    RMA161 = 'RMA161'

    RMA162 = 'RMA162'

    RMA163 = 'RMA163'

    RMA164 = 'RMA164'

    RMA166 = 'RMA166'

    RMA167 = 'RMA167'

    RMA170 = 'RMA170'

    RMA175 = 'RMA175'

    RMA18 = 'RMA18'

    RMA186 = 'RMA186'

    RMA19 = 'RMA19'

    RMA190 = 'RMA190'

    RMA191 = 'RMA191'

    RMA192 = 'RMA192'

    RMA193 = 'RMA193'

    RMA194 = 'RMA194'

    RMA195 = 'RMA195'

    RMA2 = 'RMA2'

    RMA20 = 'RMA20'

    RMA200 = 'RMA200'

    RMA201 = 'RMA201'

    RMA203 = 'RMA203'

    RMA204 = 'RMA204'

    RMA205 = 'RMA205'

    RMA207 = 'RMA207'

    RMA21 = 'RMA21'

    RMA210 = 'RMA210'

    RMA214 = 'RMA214'

    RMA217 = 'RMA217'

    RMA218 = 'RMA218'

    RMA22 = 'RMA22'

    RMA220 = 'RMA220'

    RMA223 = 'RMA223'

    RMA224 = 'RMA224'

    RMA227 = 'RMA227'

    RMA228 = 'RMA228'

    RMA230 = 'RMA230'

    RMA231 = 'RMA231'

    RMA234 = 'RMA234'

    RMA242 = 'RMA242'

    RMA245 = 'RMA245'

    RMA246 = 'RMA246'

    RMA25 = 'RMA25'

    RMA251 = 'RMA251'

    RMA254 = 'RMA254'

    RMA256 = 'RMA256'

    RMA258 = 'RMA258'

    RMA259 = 'RMA259'

    RMA26 = 'RMA26'

    RMA260 = 'RMA260'

    RMA262 = 'RMA262'

    RMA265 = 'RMA265'

    RMA268 = 'RMA268'

    RMA269 = 'RMA269'

    RMA270 = 'RMA270'

    RMA271 = 'RMA271'

    RMA273 = 'RMA273'

    RMA276 = 'RMA276'

    RMA279 = 'RMA279'

    RMA28 = 'RMA28'

    RMA280 = 'RMA280'

    RMA29 = 'RMA29'

    RMA3 = 'RMA3'

    RMA32 = 'RMA32'

    RMA33 = 'RMA33'

    RMA38 = 'RMA38'

    RMA41 = 'RMA41'

    RMA45 = 'RMA45'

    RMA46 = 'RMA46'

    RMA47 = 'RMA47'

    RMA49 = 'RMA49'

    RMA5 = 'RMA5'

    RMA50 = 'RMA50'

    RMA5005 = 'RMA5005'

    RMA5020 = 'RMA5020'

    RMA5085 = 'RMA5085'

    RMA5086 = 'RMA5086'

    RMA5091 = 'RMA5091'

    RMA5126 = 'RMA5126'

    RMA5145 = 'RMA5145'

    RMA55 = 'RMA55'

    RMA56 = 'RMA56'

    RMA57 = 'RMA57'

    RMA58 = 'RMA58'

    RMA59 = 'RMA59'

    RMA6 = 'RMA6'

    RMA60 = 'RMA60'

    RMA6001 = 'RMA6001'

    RMA6003 = 'RMA6003'

    RMA6004 = 'RMA6004'

    RMA6005 = 'RMA6005'

    RMA6010 = 'RMA6010'

    RMA6012 = 'RMA6012'

    RMA6013 = 'RMA6013'

    RMA6017 = 'RMA6017'

    RMA6018 = 'RMA6018'

    RMA6021 = 'RMA6021'

    RMA6027 = 'RMA6027'

    RMA6028 = 'RMA6028'

    RMA6029 = 'RMA6029'

    RMA6030 = 'RMA6030'

    RMA6031 = 'RMA6031'

    RMA6032 = 'RMA6032'

    RMA6033 = 'RMA6033'

    RMA6034 = 'RMA6034'

    RMA6035 = 'RMA6035'

    RMA6036 = 'RMA6036'

    RMA6037 = 'RMA6037'

    RMA6038 = 'RMA6038'

    RMA6039 = 'RMA6039'

    RMA6040 = 'RMA6040'

    RMA6042 = 'RMA6042'

    RMA6045 = 'RMA6045'

    RMA6046 = 'RMA6046'

    RMA6051 = 'RMA6051'

    RMA6052 = 'RMA6052'

    RMA6053 = 'RMA6053'

    RMA6054 = 'RMA6054'

    RMA6055 = 'RMA6055'

    RMA6056 = 'RMA6056'

    RMA6057 = 'RMA6057'

    RMA6058 = 'RMA6058'

    RMA6059 = 'RMA6059'

    RMA6060 = 'RMA6060'

    RMA6061 = 'RMA6061'

    RMA6062 = 'RMA6062'

    RMA6063 = 'RMA6063'

    RMA6064 = 'RMA6064'

    RMA6065 = 'RMA6065'

    RMA6066 = 'RMA6066'

    RMA6067 = 'RMA6067'

    RMA6068 = 'RMA6068'

    RMA6071 = 'RMA6071'

    RMA6072 = 'RMA6072'

    RMA6073 = 'RMA6073'

    RMA6074 = 'RMA6074'

    RMA6075 = 'RMA6075'

    RMA6076 = 'RMA6076'

    RMA6077 = 'RMA6077'

    RMA6078 = 'RMA6078'

    RMA6079 = 'RMA6079'

    RMA6080 = 'RMA6080'

    RMA6081 = 'RMA6081'

    RMA6082 = 'RMA6082'

    RMA6083 = 'RMA6083'

    RMA6084 = 'RMA6084'

    RMA6085 = 'RMA6085'

    RMA6086 = 'RMA6086'

    RMA6087 = 'RMA6087'

    RMA6088 = 'RMA6088'

    RMA6089 = 'RMA6089'

    RMA6090 = 'RMA6090'

    RMA6091 = 'RMA6091'

    RMA6092 = 'RMA6092'

    RMA6093 = 'RMA6093'

    RMA6094 = 'RMA6094'

    RMA6095 = 'RMA6095'

    RMA6096 = 'RMA6096'

    RMA6097 = 'RMA6097'

    RMA6098 = 'RMA6098'

    RMA6099 = 'RMA6099'

    RMA61 = 'RMA61'

    RMA6100 = 'RMA6100'

    RMA6101 = 'RMA6101'

    RMA6102 = 'RMA6102'

    RMA6103 = 'RMA6103'

    RMA6104 = 'RMA6104'

    RMA6105 = 'RMA6105'

    RMA6106 = 'RMA6106'

    RMA6107 = 'RMA6107'

    RMA6108 = 'RMA6108'

    RMA6109 = 'RMA6109'

    RMA6110 = 'RMA6110'

    RMA6111 = 'RMA6111'

    RMA6112 = 'RMA6112'

    RMA6113 = 'RMA6113'

    RMA6114 = 'RMA6114'

    RMA6115 = 'RMA6115'

    RMA6116 = 'RMA6116'

    RMA6117 = 'RMA6117'

    RMA6118 = 'RMA6118'

    RMA6119 = 'RMA6119'

    RMA6120 = 'RMA6120'

    RMA6121 = 'RMA6121'

    RMA6122 = 'RMA6122'

    RMA6123 = 'RMA6123'

    RMA6124 = 'RMA6124'

    RMA6125 = 'RMA6125'

    RMA6126 = 'RMA6126'

    RMA6127 = 'RMA6127'

    RMA6128 = 'RMA6128'

    RMA6129 = 'RMA6129'

    RMA6130 = 'RMA6130'

    RMA6131 = 'RMA6131'

    RMA6132 = 'RMA6132'

    RMA6133 = 'RMA6133'

    RMA6134 = 'RMA6134'

    RMA6135 = 'RMA6135'

    RMA6136 = 'RMA6136'

    RMA6137 = 'RMA6137'

    RMA6138 = 'RMA6138'

    RMA6139 = 'RMA6139'

    RMA6140 = 'RMA6140'

    RMA6141 = 'RMA6141'

    RMA6142 = 'RMA6142'

    RMA6144 = 'RMA6144'

    RMA6145 = 'RMA6145'

    RMA6146 = 'RMA6146'

    RMA6147 = 'RMA6147'

    RMA6148 = 'RMA6148'

    RMA6149 = 'RMA6149'

    RMA6150 = 'RMA6150'

    RMA6151 = 'RMA6151'

    RMA6152 = 'RMA6152'

    RMA6153 = 'RMA6153'

    RMA6154 = 'RMA6154'

    RMA6155 = 'RMA6155'

    RMA6156 = 'RMA6156'

    RMA6157 = 'RMA6157'

    RMA6158 = 'RMA6158'

    RMA63 = 'RMA63'

    RMA64 = 'RMA64'

    RMA67 = 'RMA67'

    RMA68 = 'RMA68'

    RMA69 = 'RMA69'

    RMA7 = 'RMA7'

    RMA72 = 'RMA72'

    RMA77 = 'RMA77'

    RMA78 = 'RMA78'

    RMA8 = 'RMA8'

    RMA80 = 'RMA80'

    RMA81 = 'RMA81'

    RMA85 = 'RMA85'

    RMA86 = 'RMA86'

    RMA88 = 'RMA88'

    RMA89 = 'RMA89'

    RMA9 = 'RMA9'

    RMA91 = 'RMA91'

    RMA92 = 'RMA92'

    RMA94 = 'RMA94'

    RMA97 = 'RMA97'

    RMA98 = 'RMA98'

    RMA99 = 'RMA99'

    RST101 = 'RST101'

    RST104 = 'RST104'

    RST105 = 'RST105'

    RST108 = 'RST108'

    RST111 = 'RST111'

    RST112 = 'RST112'

    RST116 = 'RST116'

    RST117 = 'RST117'

    RST120 = 'RST120'

    RST123 = 'RST123'

    RST127 = 'RST127'

    RST129 = 'RST129'

    RST13 = 'RST13'

    RST133 = 'RST133'

    RST134 = 'RST134'

    RST137 = 'RST137'

    RST14 = 'RST14'

    RST149 = 'RST149'

    RST151 = 'RST151'

    RST156 = 'RST156'

    RST157 = 'RST157'

    RST160 = 'RST160'

    RST161 = 'RST161'

    RST169 = 'RST169'

    RST170 = 'RST170'

    RST171 = 'RST171'

    RST172 = 'RST172'

    RST173 = 'RST173'

    RST174 = 'RST174'

    RST175 = 'RST175'

    RST176 = 'RST176'

    RST177 = 'RST177'

    RST178 = 'RST178'

    RST179 = 'RST179'

    RST180 = 'RST180'

    RST181 = 'RST181'

    RST182 = 'RST182'

    RST183 = 'RST183'

    RST184 = 'RST184'

    RST185 = 'RST185'

    RST186 = 'RST186'

    RST187 = 'RST187'

    RST20 = 'RST20'

    RST25 = 'RST25'

    RST34 = 'RST34'

    RST35 = 'RST35'

    RST4 = 'RST4'

    RST5028 = 'RST5028'

    RST60 = 'RST60'

    RST63 = 'RST63'

    RST65 = 'RST65'

    RST67 = 'RST67'

    RST68 = 'RST68'

    RST7 = 'RST7'

    RST71 = 'RST71'

    RST73 = 'RST73'

    RST74 = 'RST74'

    RST79 = 'RST79'

    RST80 = 'RST80'

    RST82 = 'RST82'

    RST86 = 'RST86'

    RST87 = 'RST87'

    RST9 = 'RST9'

    RST92 = 'RST92'

    RST96 = 'RST96'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TimeCostParkingEnum(object):

    """Implementation of the 'TimeCostParkingEnum' enum.

    TODO: type enum description here.

    Attributes:
        PERHOUR: TODO: type description here.
        PERWEEK: TODO: type description here.
        PERSTAY: TODO: type description here.
        PERDAY: TODO: type description here.

    """

    PERHOUR = 'PerHour'

    PERWEEK = 'PerWeek'

    PERSTAY = 'PerStay'

    PERDAY = 'PerDay'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class WeekendParamEnum(object):

    """Implementation of the 'WeekendParamEnum' enum.

    TODO: type enum description here.

    Attributes:
        DAYS_OF_WEEKEND_SAT_SUN: TODO: type description here.
        DAYS_OF_WEEKEND_FRI_SAT: TODO: type description here.
        DAYS_OF_WEEKEND_FRI_SAT_SUN: TODO: type description here.
        DAYS_OF_WEEKEND_THU_FRI_SAT: TODO: type description here.
        DAYS_OF_WEEKEND_THU_FRI_SAT_SUN: TODO: type description here.

    """

    DAYS_OF_WEEKEND_SAT_SUN = 'DAYS_OF_WEEKEND_SAT_SUN'

    DAYS_OF_WEEKEND_FRI_SAT = 'DAYS_OF_WEEKEND_FRI_SAT'

    DAYS_OF_WEEKEND_FRI_SAT_SUN = 'DAYS_OF_WEEKEND_FRI_SAT_SUN'

    DAYS_OF_WEEKEND_THU_FRI_SAT = 'DAYS_OF_WEEKEND_THU_FRI_SAT'

    DAYS_OF_WEEKEND_THU_FRI_SAT_SUN = 'DAYS_OF_WEEKEND_THU_FRI_SAT_SUN'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeValueTypeEnum(object):

    """Implementation of the 'FeeValueTypeEnum' enum.

    Value Type {FLAT, PERCENT}

    Attributes:
        FLAT: TODO: type description here.
        PERCENT: TODO: type description here.

    """

    FLAT = 'FLAT'

    PERCENT = 'PERCENT'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.description_text_model

class Notes(object):

    """Implementation of the 'Notes' model.

    Model where you can define different kinds of text values. If you need to
    delete some kind of texts, for example short description, you can do this
    on Update call (PUT), and you need to pass empty array for texts value,
    for example :  "shortDescription": {  "texts": [  ] }

    Attributes:
        description (DescriptionTextModel): Model for any kind of description
            text in Property object
        house_rules (DescriptionTextModel): Model for any kind of description
            text in Property object
        fine_print (DescriptionTextModel): Model for any kind of description
            text in Property object
        short_description (DescriptionTextModel): Model for any kind of
            description text in Property object
        name (DescriptionTextModel): Model for any kind of description text in
            Property object

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description":'description',
        "house_rules":'houseRules',
        "fine_print":'finePrint',
        "short_description":'shortDescription',
        "name":'name'
    }

    def __init__(self,
                 description=None,
                 house_rules=None,
                 fine_print=None,
                 short_description=None,
                 name=None):
        """Constructor for the Notes class"""

        # Initialize members of the class
        self.description = description
        self.house_rules = house_rules
        self.fine_print = fine_print
        self.short_description = short_description
        self.name = name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        description = apimaticcalculatorlatest.models.description_text_model.DescriptionTextModel.from_dictionary(dictionary.get('description')) if dictionary.get('description') else None
        house_rules = apimaticcalculatorlatest.models.description_text_model.DescriptionTextModel.from_dictionary(dictionary.get('houseRules')) if dictionary.get('houseRules') else None
        fine_print = apimaticcalculatorlatest.models.description_text_model.DescriptionTextModel.from_dictionary(dictionary.get('finePrint')) if dictionary.get('finePrint') else None
        short_description = apimaticcalculatorlatest.models.description_text_model.DescriptionTextModel.from_dictionary(dictionary.get('shortDescription')) if dictionary.get('shortDescription') else None
        name = apimaticcalculatorlatest.models.description_text_model.DescriptionTextModel.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None

        # Return an object of this model
        return cls(description,
                   house_rules,
                   fine_print,
                   short_description,
                   name)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class NearbyAmenity(object):

    """Implementation of the 'NearbyAmenity' model.

    TODO: type model description here.

    Attributes:
        attribute_id (NearbyAmenitiesEnum): List of allowed Nearby Amenities
            codes
        distance (int): Will be set to 0 by default

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "attribute_id":'attributeId',
        "distance":'distance'
    }

    def __init__(self,
                 attribute_id=None,
                 distance=None):
        """Constructor for the NearbyAmenity class"""

        # Initialize members of the class
        self.attribute_id = attribute_id
        self.distance = distance


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        attribute_id = dictionary.get('attributeId')
        distance = dictionary.get('distance')

        # Return an object of this model
        return cls(attribute_id,
                   distance)


